@@ -192,7 +192,7 @@ OC.L10N.register(
     "Call in progress" : "Llamada en cursu",
     "You were mentioned" : "Mentáronte",
     "Write to conversation" : "Escribi na conversación",
-    "You were invited to a conversation." : "Convidáronte a una conversación.",
+    "Description" : "Descripción",
     "Private conversation" : "Conversación privada",
     "Failed to upload call recording" : "Nun se pue xubir la grabación de la llamada",
     "Dismiss notification" : "Escargar l'avisu",
@@ -211,7 +211,6 @@ OC.L10N.register(
     "View message" : "Ver el mensaxe",
     "Dismiss reminder" : "Escartar el recordatoriu",
     "View chat" : "Ver la charra",
-    "{user} invited you to a private conversation" : "{user} convidóte a una conversación privada",
     "Join call" : " Xunise a la llamada",
     "Answer call" : "Contestar a la llamada",
     "{user} would like to talk with you" : "{user} quier falar contigo",
@@ -484,7 +483,6 @@ OC.L10N.register(
     "Bots settings" : "Configuración de los robós",
     "State" : "Estáu",
     "Name" : "Nome",
-    "Description" : "Descripción",
     "Total errors count" : "Númberu d'errores totales",
     "Find more bots" : "Atopar más robós",
     "Beta" : "Beta",
@@ -627,6 +625,8 @@ OC.L10N.register(
     "Show Matterbridge log" : "Amosar el rexistru de Matterbridge",
     "Log content" : "Conteníu del rexistru",
     "Notifications" : "Avisos",
+    "Error while creating the conversation" : "Hebo un error mentanto se creaba la conversación",
+    "Create conversation" : "Crear una conversación",
     "Log in" : "Aniciar la sesión",
     "An error occurred while calling a phone number" : "Prodúxose un error mentanto se llamaba a un númberu de teléfonu",
     "Phone number could not be called: {error}" : "Nun se pudo llamar al númberu de teléfonu: {error}",
@@ -638,6 +638,7 @@ OC.L10N.register(
     "Decline invitation" : "Refugar la invitación",
     "Accept invitation" : "Aceptar la invitación",
     "No pending invitations" : "Nun hai nenguna invitación pendiente",
+    "Unread" : "Ensin lleer",
     "No matches found" : "Nun s'atopó nenguna coincidencia",
     "No conversations found" : "Nun s'atopó nenguna conversación",
     "You have no unread mentions." : "Nun tienes nenguna mención ensin lleer.",
@@ -721,8 +722,6 @@ OC.L10N.register(
     "A week ago" : "Hai una selmana",
     "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
     "No messages" : "Nun hai nengún mensaxe",
-    "Error while creating the conversation" : "Hebo un error mentanto se creaba la conversación",
-    "Create conversation" : "Crear una conversación",
     "Add participants" : "Amestar participantes",
     "Conversation visibility" : "Visibilidá de la conversación",
     "This conversation has been locked" : "Bloquióse esta conversación",
@@ -951,20 +950,11 @@ OC.L10N.register(
     "Notes" : "Notes",
     "Reports" : "Informes",
     "Call summary" : "Resume de llamaes",
-    "The command does not exist" : "El comandu nun esiste",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Prodúxose un error mentanto s'executaba'l comandu. Pidi a l'alministración que compruebe los rexistros.",
     "You tried to call {user}" : "Tentesti de llamar a {user}",
-    "Moderators" : "Moderadores",
-    "Commands" : "Comandos",
-    "Command" : "Comandu",
-    "Script" : "Script",
-    "The message could not be sent" : "Nun se pudo unviar el mensaxe",
+    "You were invited to a conversation." : "Convidáronte a una conversación.",
+    "{user} invited you to a private conversation" : "{user} convidóte a una conversación privada",
     "Copy conversation link" : "Copiar l'enllaz de la conversación",
-    "Channel ID or name" : "ID o nome de la canal",
-    "Loading" : "Cargando",
     "Close" : "Zarrar",
-    "Private poll" : "Encuesta privada",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada.",
-    "TURN server" : "Sirividor TURN"
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada."
 },
 "nplurals=2; plural=(n != 1);");
