@@ -107,11 +107,8 @@ OC.L10N.register(
     "You were mentioned" : "Meneget oc'h bet",
     "Write to conversation" : "Skrivañ d'an diviz",
     "Writes event information into a conversation of your choice" : "Skriva titouroù an darvout en diviz o peus c'hoant",
-    "%s invited you to a conversation." : "%s en deus kouviet ac'hanoc'h dan diviz",
-    "You were invited to a conversation." : "Kouviet oc'h en un diviz",
     "Conversation invitation" : "Kouviadenn diviz",
-    "Click the button below to join." : "Klikit war ar bouton evit mont",
-    "Join »%s«" : "Mont da »%s«",
+    "Description" : "Deskrivadur",
     "Password request: %s" : "Ger-tremen goulennet : %s",
     "Private conversation" : "Diviz prevez",
     "Deleted user (%s)" : "Implijour dilamet (%s)",
@@ -466,7 +463,6 @@ OC.L10N.register(
     "Disabled" : "Disaotreañ",
     "State" : "Stad",
     "Name" : "Anv",
-    "Description" : "Deskrivadur",
     "Beta" : "Beta",
     "All messages" : "Pep kemenadenn",
     "@-mentions only" : "@-meneg nemetkenn",
@@ -591,6 +587,7 @@ OC.L10N.register(
     "Go to file" : "Mont d'ar restr",
     "Translate" : "Treiñ",
     "Dismiss" : "Arrest",
+    "Translate to" : "Treiñ e",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
     "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
@@ -715,39 +712,17 @@ OC.L10N.register(
     "iOS app" : "Meziant iOS",
     "__language_name__" : "Brezhoneg",
     "Notes" : "Notennoù",
-    "There are currently no commands available." : "N'ez us linenn urzh ebet evit ar poent",
-    "The command does not exist" : "N'ez eus ket eyus an urzh",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ur fazi a zo bet en ur ober an urzh. Goulennit d'ar merour da sellet ouzh ar gazetenn.",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Kemenadenn gant {user1} ha {user2} (Padelez {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Kemenadenn gant {user1}, {user2} ha {user3} (Padelez {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3} ha {user4} (Padelez {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3}, {user4} ha {user5} (Padelez {duration})",
+    "%s invited you to a conversation." : "%s en deus kouviet ac'hanoc'h dan diviz",
+    "You were invited to a conversation." : "Kouviet oc'h en un diviz",
+    "Click the button below to join." : "Klikit war ar bouton evit mont",
+    "Join »%s«" : "Mont da »%s«",
     "{user} invited you to a private conversation" : "{user} en deus kouviet ac'hanoc'h en un diviz prevez",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "An urzhioù a zo ur perzh nevez e Nextcloud Talk. Aotreañ a reont da lakaat da dreiñ ur skrip war ho servijour Nextcloud. Galout a rit krouañ anezho en ur implij hon etrafas linenn urzh. Ur skouer skript jederez a zo posupl kaout en hon {linkstart}diellvadur{linkend}.",
-    "Moderators" : "Habaskaer",
-    "Commands" : "Urzhioù",
-    "Command" : "Urzh",
-    "Script" : "Script",
-    "Response to" : "Respont da",
-    "Enabled for" : "reañ evit",
-    "Hosted high-performance backend" : "Backend a labour buhan osted",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour diavaezh arhentañ a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhentañ diabarzh goulo.",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Aliet kreñv eo staliañ ur c'hach rannet pa implijer Nextcloud Talk gant ur Vack-End Labour Huel.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "N'om pas kemenn diwar ben kudennom kenstagadur er gemennadennoù gant muioc'h eget 4 implijer.",
     "Copy conversation link" : "Eilañ al liamm diviz",
-    "Loading" : "Kargañ",
     "Close" : "Serriñ",
-    "Password protect" : "Ger-tremen gwarezet",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
     "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
     "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
     "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
-    "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn.",
-    "Specify commands the users can use in chats" : "Lakait peseurt urzhioù eo posupl d'an implijer implij er chat",
-    "TURN server" : "Servijour TRUN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Ar servijour TURN a zo implijet evit proksiañ froud an implijaderien a-drek ur voger-dan.",
-    "Signaling servers" : "Arhent Servijour",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour arhent diavaez a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhent diabarzh goullo."
+    "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
