@@ -11,6 +11,7 @@ OC.L10N.register(
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
+    "Description" : "Descripción",
     "Dismiss notification" : "Eliminar notificación",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
@@ -29,7 +30,6 @@ OC.L10N.register(
     "Disabled" : "Deshabilitado",
     "State" : "Estado",
     "Name" : "Nombre",
-    "Description" : "Descripción",
     "Beta" : "Beta",
     "Permissions" : "Permisos",
     "Off" : "Apagado",
@@ -147,10 +147,6 @@ OC.L10N.register(
     "Tasks" : "Tareas",
     "Notes" : "Notas",
     "Reports" : "Reportes",
-    "Loading" : "Cargando",
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. "
+    "Close" : "Cerrar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
