@@ -80,11 +80,8 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Talk mentions" : "Menciones en Talk",
     "No unread mentions" : "No hay menciones sin leer",
-    "%s invited you to a conversation." : "%s te invitó a una conversación",
-    "You were invited to a conversation." : "fuiste invitado a una conversación",
     "Conversation invitation" : "invitación a una conversación",
-    "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
-    "Join »%s«" : "Unirse »%s«",
+    "Description" : "Descripción",
     "Password request: %s" : "Solicitud de Password: %s",
     "Private conversation" : "Conversación privada",
     "Deleted user (%s)" : "Usuario eliminado (%s)",
@@ -93,9 +90,8 @@ OC.L10N.register(
     "Decline" : "Rechazar",
     "{user} sent you a private message" : "{user} te envió un mensaje privado",
     "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
-    "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
-    "Join call" : "Unirse a la llamada",
     "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
+    "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "error" : "error",
@@ -330,7 +326,6 @@ OC.L10N.register(
     "Disabled" : "Deshabilitado",
     "State" : "Estado",
     "Name" : "Nombre",
-    "Description" : "Descripción",
     "Beta" : "Beta",
     "Permissions" : "Permisos",
     "@-mentions only" : "Solo menciones con @",
@@ -406,6 +401,7 @@ OC.L10N.register(
     "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
+    "Unread" : "No leído",
     "Clear filter" : "Limpiar filtro",
     "Unread mentions" : "Menciones sin leer",
     "Users" : " Usuarios",
@@ -514,20 +510,11 @@ OC.L10N.register(
     "Tasks" : "Tareas",
     "Notes" : "Notas",
     "Reports" : "Informes",
-    "There are currently no commands available." : "No hay comandos disponibles actualmente",
-    "The command does not exist" : "El comando no existe",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
-    "Command" : "Comando",
-    "Loading" : "Cargando",
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
+    "%s invited you to a conversation." : "%s te invitó a una conversación",
+    "You were invited to a conversation." : "fuiste invitado a una conversación",
+    "Click the button below to join." : "Haz click en el botón de abajo para unirte.",
+    "Join »%s«" : "Unirse »%s«",
+    "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
+    "Close" : "Cerrar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
