@@ -1,10 +1,19 @@
 OC.L10N.register(
     "spreed",
     {
+    "(Duration %s)" : "(kestus %s)",
+    "You attended a call with {user1}" : "Sa osalesid kõnes kasutajaga {user1}",
     "_%n guest_::_%n guests_" : ["%n külaline","%n külalist"],
+    "You attended a call with {user1} and {user2}" : "Sa osalesid kõnes kasutajatega {user1} ja {user2}",
+    "You attended a call with {user1}, {user2} and {user3}" : "Sa osalesid kõnes kasutajatega {user1}, {user2} ja {user3}",
+    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Sa osalesid kõnes kasutajatega {user1}, {user2}, {user3} ja {user4}",
+    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Sa osalesid kõnes kasutajatega {user1}, {user2}, {user3}, {user4} ja {user5}",
+    "_%n other_::_%n others_" : ["%n muu","%n muud"],
+    "{actor} invited you to {call}" : "{actor} kutsus sind osalema „{call}“ kõnes ",
     "Other activities" : "Muud tegevused",
     "Talk" : "Talk",
     "Guest" : "Külaline",
+    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Vestlustel on nüüd ooteruum. See võimaldab moderaatoritel liituda ettevalmistamiseks vestluse või kõnega ning muud osalejad ja külalised asuvad seni ooteruumis,",
     "You created the conversation" : "Sina lõid selle vestluse",
     "{actor} removed the description" : "{actor} eemaldas kirjelduse",
     "You removed the description" : "Sina eemaldasid kirjelduse",
@@ -58,17 +67,31 @@ OC.L10N.register(
     "Message deleted by you" : "Sina kustutasid sõnumi",
     "Administration" : "Haldus",
     "System" : "Süsteem",
+    "%s (guest)" : "%s (külaline)",
     "Missed call" : "Märkamata kõne",
     "Unanswered call" : "Vastamata kõne",
+    "Talk to %s" : "Suhtle: %s",
     "File is too big" : "Fail on liiga suur",
     "Invalid file provided" : "Vigane fail",
     "Invalid image" : "Vigane pilt",
     "Unknown filetype" : "Tundmatu failitüüp",
+    "%1$s invited you to conversation \"%2$s\"." : "%1$s kutsus sind „%2$s“ vestlusesse.",
+    "You were invited to conversation \"%s.\"" : "Sa said kutse „%s“ vestlusesse.",
+    "Scheduled time" : "Plaanitud aeg",
+    "Description" : "Kirjeldus",
+    "Click the button below to join the lobby now." : "Ooteruumiga liitumiseks vajuta allolevat nuppu.",
+    "Click the link below to join the lobby now." : "Ooteruumiga liitumiseks vajuta allolevat linki.",
+    "Join lobby for \"%s\"" : "Sisene „%s“ ooteruumi",
+    "Click the button below to join the conversation now." : "Vestlusega liitumiseks vajuta allolevat nuppu.",
+    "Click the link below to join the conversation now." : "Vestlusega liitumiseks vajuta allolevat linki.",
+    "Join \"%s\"" : "Liitu: „%s“",
     "Dismiss notification" : "Sulge teavitus",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
     "{user} mentioned team {team} in conversation {call}" : "{user} mainis „{team}“ tiimi „{call}“ vestluses",
     "A deleted user mentioned team {team} in conversation {call}" : "Kustutatud kasutaja mainis „{team}“ tiimi „{call}“ vestluses",
+    "{guest} (guest) mentioned team {team} in conversation {call}" : "„{guest}“ (külaline) mainis „{call}“ vestluses „{team}“ tiimi",
+    "A guest mentioned team {team} in conversation {call}" : "Külaline mainis „{call}“ vestluses „{team}“ tiimi",
     "Join call" : "Liitu kõnega",
     "You missed a call from {user}" : "Vastamata kõne kasutajalt {user}",
     "You missed a group call in {call}" : "Vastamata kõne grupis {call}",
@@ -78,6 +101,7 @@ OC.L10N.register(
     "Avatar image is not square" : "Avatari pilt pole ruut",
     "Note to self" : "Minu märkmed",
     "Let's get started!" : "Alustame!",
+    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in a the conversation %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Lase vestlusel kulgeda: maini kasutajaid, reageeri sõnumitele ja palju muud\n\n„%s“ vestluses saadi mainida kõiki või ühte konkreetset osaleja, selleks sisesta „@“ vali loendist soovitud nimi.",
     "You can reply to messages, forward them to other chats and people, or copy message content." : "Sa võid sõnumitele vastata, neid teistesse vestlustesse või teistele kasutajatele edastada ning kopeerida sõnumite sisu.",
     "Denmark" : "Taani",
     "Federation" : "Liidendus",
@@ -104,7 +128,8 @@ OC.L10N.register(
     "Disabled" : "Keelatud",
     "State" : "Olek",
     "Name" : "Nimi",
-    "Description" : "Kirjeldus",
+    "Permissions" : "Õigused",
+    "Off" : "Pole kasutusel",
     "End-to-end encrypted calls" : "Läbivalt krüptitud kõned",
     "Enable encryption" : "Luba krüptimine",
     "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Seadistatud SIP-i võrgusilla vahendusel tehtavad läbivalt krüptitud kõned eeldavad uuema suure jõudlusega taustateenuse ja SIP-i võrgusilla kasutamist.",
@@ -147,18 +172,26 @@ OC.L10N.register(
     "{participant0} will receive an invitation" : "{participant0} saab kutse",
     "{participant0} and {participant1} will receive invitations" : "{participant0} ja {participant1} saavad kutse",
     "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} ja %n muu kasutaja saavad kutse","{participant0}, {participant1} ja %n muud kasutajat saavad kutse"],
+    "Invite {user}" : "Saada kutse kasutajale {user}",
+    "Invite all users and emails in this conversation" : "Saada kutse kõikidele selle vestluse kasutajatele ja e-posti aadressidele",
+    "Meeting created" : "Kohtumine on loodud",
+    "Upcoming meetings" : "Tulekul kohtumised",
+    "Next meeting" : "Järgmine kohtumine",
     "Loading …" : "Laadimine ...",
     "No upcoming events" : "Tulekul sündmuseid pole",
+    "Schedule a meeting" : "Ajasta kohtumine",
+    "Meeting title" : "Kohtumise nimi",
     "From" : "Saatja",
     "To" : "Saaja",
     "Calendar" : "Kalender",
     "Attendees" : "Osalejad",
-    "Invite all users and emails" : "Kutsu kõiki kasutajaid ja e-posti aadresse",
+    "No other participants to send invitations to." : "Pole ühtegi teist osalejat, kellele kutset saata.",
     "Add attendees" : "Lisa osalejaid",
     "Save" : "Salvesta",
     "Search participants" : "Otsi osalejaid",
     "No results" : "Vasteid ei leitud",
     "Done" : "Valmis",
+    "Lobby is still active and you're not a moderator" : "Ooteruum on jätkuvalt kasutusel ja sina pole moderaator",
     "A participant raised their hand." : "Üks osaleja andis käega märku",
     "Copy link" : "Kopeeri link",
     "You" : "Sina",
@@ -179,22 +212,65 @@ OC.L10N.register(
     "The file must be a PNG or JPG" : "Fail peab olema png või jpg vormingus",
     "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Muuda kasutajate vaikimisi õigusi siin vestluses. See ei mõjuuta moderaatorite õigusi.",
     "Restricted" : "Piiratud",
+    "Advanced permissions" : "Täiendavad õigused",
     "Edit permissions" : "Muuda õigusi",
+    "Conversation settings" : "Vestluse seadistused",
+    "Basic Info" : "Põhiteave",
     "Personal" : "Isiklik",
+    "Moderation" : "Modereerimine",
+    "Setup overview" : "Seadistuse ülevaade",
+    "Breakout Rooms" : "Eraldi jututoad",
+    "Matterbridge" : "Matterbridge",
+    "Bots" : "Võrgurobotid",
+    "Danger zone" : "Ohtlik - siin ole ettevaatlik",
+    "Archive conversation" : "Arhiveeri vestlus",
+    "Do you really want to leave \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoast lahkuda?",
+    "Do you really want to delete \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoa kustutada?",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Kas sa kindlasti soovid „{displayName}“ jututoast kõik vestlused kustutada?",
     "You need to promote a new moderator before you can leave the conversation" : "Pead määrama uue moderaatori enne siit vestlusest lahkumist",
+    "Error while deleting conversation" : "Viga vestluse kustutamisel",
+    "Error while clearing chat history" : "Viga vestluse ajaloo kustutamisel",
+    "Be careful, these actions cannot be undone." : "Palun ole ettevaatlik - neid tegevusi ei saa tagasi pöörata.",
+    "Leave conversation" : "Lahku vestlusest",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Kui lahkud kinnisest vestlusest, siis vajad uuesti liitumiseks luba. Avatud vestlusega saad liituda omal äranägemisel.",
+    "You can archive this conversation instead." : "Selle asemel võid antud vestluse arhiveerida.",
     "No" : "Ei",
     "Yes" : "Ja",
     "Delete conversation" : "Kustuta vestlus",
+    "Permanently delete this conversation." : "Kustuta see vestlus jäädavalt.",
+    "Delete chat messages" : "Kustuta vestluse sõnumid",
+    "Permanently delete all the messages in this conversation." : "Kustuta jäädavalt kõik selle vestluse sõnumid.",
+    "Delete all chat messages" : "Kustuta kõik vestluse sõnumid",
     "_%n hour_::_%n hours_" : ["%n tund","%n tundi"],
     "_%n day_::_%n days_" : ["%n päev","%n päeva"],
+    "_%n week_::_%n weeks_" : ["%n nädal","%n nädalat"],
+    "Custom expiration time" : "Sinu valitud aegumine",
+    "Message expiration disabled" : "Sõnumi aegumine pole kasutusel",
+    "Message expiration set: {duration}" : "Sõnum aegub: {duration}",
+    "Error when trying to set message expiration" : "Viga sõnumi aegumise määramisel",
+    "Message expiration" : "Sõnumi aegumine",
+    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Vestluse sõnumid saad määrata kustuma etteantud aja järel. Palun arvesta, et sel juhul vestluses jagatud failid jäävad omaniku jaoks nähtavaks, aga pole enam vestluse jaoks jagatud.",
+    "Set message expiration" : "Määra sõnumi aegumine",
+    "Current message expiration" : "Sõnumi aegumine",
+    "Password copied to clipboard" : "Salasõna on kopeeritud lõikelauale.",
+    "Password could not be copied" : "Salasõna ei õnnestunud lõikelauale kopeerida.",
     "Password protection" : "Password protection",
+    "Set a password" : "Lisa salasõna",
+    "Enter new password" : "Sisesta uus salasõna",
+    "Save password" : "Salvesta salasõna",
     "Copy password" : "Kopeeri salasõna",
+    "Guests are allowed to join this conversation via link" : "Külalised võivad selle vestlusega lingi alusel liituda",
+    "Guests are not allowed to join this conversation" : "Külalised ei või selle vestlusega liituda",
+    "Resend invitations" : "Saada kutsed uuesti",
+    "Enabling the lobby will remove non-moderators from the ongoing call." : "Ooteruumi sisselülitamine selle kõne jaoks eemaldab kõik tavakasutajad (i.e. kes pole moderaatorid) sellest pooleliolevast kõnest.",
+    "Enable lobby, restricting the conversation to moderators" : "Lülita sisse ooteruum ja piira osalemine vaid moderaatoritega",
     "Lock conversation" : "Lukusta vestlus",
     "Edit" : "Muuda",
     "Delete" : "Kustuta",
     "Log content" : "Logi sisu",
     "Notifications" : "Teavitused",
     "Error while creating the conversation" : "Viga vestluse loomisel",
+    "Start a group conversation" : "Alusta rühmavestlust",
     "Create conversation" : "Loo vestlus",
     "Enter your name" : "Sisesta oma nimi",
     "Log in" : "Logi sisse",
@@ -205,18 +281,23 @@ OC.L10N.register(
     "Add to favorites" : "Lisa lemmikutesse",
     "You need to promote a new moderator before you can leave the conversation." : "Pead määrama uue moderaatori enne siit vestlusest lahkumist.",
     "Unread" : "Lugemata",
+    "Mentions" : "Mainimised",
     "An error occurred while performing the search" : "Otsimisel tekkis viga",
     "Create a new conversation" : "Loo uus vestlus",
+    "Join open conversations" : "Liitu avalike vestlustega",
     "Clear filter" : "Tühjenda filter",
+    "Unread mentions" : "Lugemata mainimised",
     "Users" : "Kasutajad",
     "Groups" : "Grupid",
     "Teams" : "Tiimid",
     "No search results" : "Otsingul pole tulemusi",
+    "You are currently waiting in the lobby" : "Sa asud hetkel ooteruumis",
     "None" : "Pole",
     "Select speaker" : "Vali esineja",
     "No speaker available" : "Esinejat pole saadaval",
     "Select a device" : "Vali seade",
     "Devices" : "Seadmed",
+    "Call without notification" : "Kõne ilma teavituseta",
     "Invalid path selected" : "Vigane asukoht on valitud",
     "Blur" : "Hägusus",
     "Upload" : "Laadi üles",
@@ -270,6 +351,7 @@ OC.L10N.register(
     "Send message silently" : "Saada sõnum vaikselt",
     "Send message" : "Saada sõnum",
     "The message could not be edited" : "Sõnumi muutmine ei õnnestunud",
+    "Add emoji" : "Lisa emoji",
     "Cancel editing" : "Katkesta muutmine",
     "Replacement:" : "Asendus:",
     "Share from Files" : "Jaga failirakendusest",
@@ -283,6 +365,7 @@ OC.L10N.register(
     "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} ja veel %n kasutaja kirjutavad…","{user1}, {user2}, {user3} ja veel %n kasutajat kirjutavad…"],
     "Send" : "Saada",
     "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Muuda kasutajate vaikimisi õigusi vestluses <strong>{conversationName}</strong>",
+    "Skip the lobby" : "Jäta ooteruum vahele",
     "Create poll in {name}" : "Loo siin küsitlus: {name}",
     "Create poll" : "Loo küsitlus",
     "Question" : "Küsimus",
@@ -291,6 +374,7 @@ OC.L10N.register(
     "(editing)" : "(muutmisel)",
     "Send a message to \"{roomName}\"" : "Saada sõnum „{roomName}“ jututuppa",
     "Send message to room" : "Saada sõnum jututuppa",
+    "Disable lobby" : "Lülita ooteruumi kasutamine välja",
     "guest" : "külaline",
     "Remove group and members" : "Eemalda gruppe ja liikmeid",
     "Remove team and members" : "Eemalda tiime ja liikmeid",
@@ -300,6 +384,8 @@ OC.L10N.register(
     "Do you really want to remove {displayName} from this conversation?" : "Kas sa kindlasti soovid eemaldada „{displayName}“ sellest vestlusest?",
     "Permissions granted to {displayName}" : "Õigused on antud kasutajale {displayName}",
     "Permissions removed for {displayName}" : "Õigused on eemaldatud kasutajalt {displayName}",
+    "in the lobby" : "ooteruumis",
+    "Move back to lobby" : "Suundu tagasi ooteruumi",
     "Promote to moderator" : "Määra moderaatoriks",
     "Copy phone number" : "Kopeeri telefoninumber",
     "Grant all permissions" : "Anna kõik õigused",
@@ -317,6 +403,7 @@ OC.L10N.register(
     "Searching …" : "Otsin ...",
     "Search for more users" : "Otsi veel kasutajaid",
     "Search or add participants" : "Otsi või lisa osalejaid",
+    "A new group conversation with selected participant will be created" : "Järgnevaga luuakse valitud osalejaga uus rühmavestlus",
     "Participants" : "Osalejad",
     "Participants ({count})" : "Osalejad ({count})",
     "Open chat" : "Ava vestlus",
@@ -330,8 +417,13 @@ OC.L10N.register(
     "Until" : "Kuni",
     "No results found" : "Otsingutulemusi ei leidu",
     "Load more results" : "Laadi veel tulemusi",
+    "Projects" : "Projektid",
+    "Select conversation" : "Vali vestlus",
     "Edit display name" : "Muuda kuvatavat nime",
+    "Your personal setting has been saved" : "Sinu isiklik seadistus on salvestatud",
+    "Error while setting personal setting" : "Viga isikliku seadistuste salvestamisel",
     "Appearance" : "Välimus",
+    "Show conversations list in compact mode" : "Näita vestluste loendit kompaktses vaates",
     "Privacy" : "Privaatsus",
     "Keyboard shortcuts" : "Klaviatuuri otseteed",
     "Edit your last message" : "Muuda oma viimast sõnumit",
@@ -343,17 +435,20 @@ OC.L10N.register(
     "Push to talk or push to mute" : "Vajuta rääkimiseks või summutamiseks",
     "Raise or lower hand" : "Anna käega märku või lõpeta märguandmine",
     "Mouse wheel" : "Hiire ratas",
-    "Zoom-in / zoom-out a screen share" : "Suuumi jagatavas ekraanis sisse/välja",
+    "Zoom-in / zoom-out a screen share" : "Suumi jagatavas ekraanis sisse/välja",
     "Start call silently" : "Helista vaikselt",
     "Start call" : "Helista",
     "End call" : "Lõpeta kõne",
     "End call for everyone" : "Lõpeta kõne kõigi jaoks",
+    "The call has been running for one hour." : "Kõne on kestnud üle tunni.",
+    "Add participants to this call" : "Lisa sellele kõnele osalejaid",
     "_%n participant in call_::_%n participants in call_" : ["Kõnes on %n osaleja","Kõnes on %n osalejat"],
     "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
     "Grid view" : "Ruudustikvaade",
     "Lower hand" : "Lase käsi alla",
     "Remove participant {name}" : "Eemalda osaleja {name}",
     "Submit" : "Saada",
+    "Search …" : "Otsi…",
     "Mention myself" : "Maini iseennast",
     "Talk conversation" : "Talk suhtlus",
     "User" : "Kasutaja",
@@ -396,7 +491,9 @@ OC.L10N.register(
     "{actor} promoted {user0} and {user1} to moderators" : "{actor} määras kasutajad {user0} ja {user1} moderaatoriteks",
     "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Peakasutaja määras kasutajad {user0} ja {user1} ning veel %n kasutaja moderaatoriteks","Peakasutaja määras kasutajad {user0} ja {user1} ning veel %n kasutajat moderaatoriteks"],
     "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} määras kasutajad {user0}, {user1} ja veel %n kasutaja moderaatoriteks","{actor} määras kasutajad {user0}, {user1} ja veel %n kasutajat moderaatoriteks"],
-    "Nextcloud Talk was updated." : "Nextcloud Talk on uuedatud.",
+    "You:" : "Sina:",
+    "{actor}:" : "{actor}:",
+    "Nextcloud Talk was updated." : "Nextcloud Talk on uuendatud.",
     "(edited)" : "(muudetud)",
     "(edited by you)" : "(muudetud sinu poolt)",
     "(edited by a deleted user)" : "(muudetud kustutatud kasutaja poolt)",
@@ -417,9 +514,12 @@ OC.L10N.register(
     "Could not delete the conversation picture" : "Vestluse pildi kustutamine ei õnnestunud",
     "Error while sharing file" : "Viga faili jagamisel",
     "Failed to join the conversation." : "Vestlusega ei õnnestunud liituda.",
+    "{guest} (guest)" : "{guest} (külaline)",
     "Failed to remove reaction" : "Regeerimise eemaldamine ei õnnestunud",
     "Nextcloud is in maintenance mode." : "Nextcloud on hooldusrežiimis.",
+    "Nextcloud Talk Federation was updated." : "Nextcloud Talk liitpilves on uuendatud.",
     "Lost connection to signaling server. Trying to reconnect." : "Kadus ühendus kõnehõlbustusserveriga. Proovi, kas ühenduse uuesti loomine aitab.",
+    "Lost connection to signaling server." : "Kadus ühendus kõnehõlbustusserveriga.",
     "Please restart the app." : "Palun käivita rakendus uuesti.",
     "Please reload the page." : "Palun laadi leht uuesti.",
     "Please try to restart the app." : "Palun proovi rakenduse uuesti käivtamist.",
@@ -435,6 +535,7 @@ OC.L10N.register(
     "iOS app" : "iOS-i rakendus",
     "__language_name__" : "Eesti",
     "Call summary (%s)" : "Kõne kokkuvõte (%s)",
+    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "See robot postitab kõne lõppedes kõikidele kõnes osalejatele ülevaatliku sõnumi, osalejate ja ülesannete andmetega",
     "Tasks" : "Ülesanded",
     "Notes" : "Märkmed",
     "Reports" : "Aruanded",
@@ -442,12 +543,9 @@ OC.L10N.register(
     "Agenda" : "Päevakava",
     "Call summary" : "Kõne kokkuvõte",
     "Call summary - {title}" : "Kõne kokkuvõte - {title}",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Suuremate paigalduste puhul peaksid kasutama täiendavat välist kõnehõlbustusserverit. Kui jätad tühjaks, on kasutusel sisseehitatud kõnehõlbustusserver.",
     "Copy conversation link" : "Kopeeri vestluse link",
-    "Loading" : "Laadimine",
     "Close" : "Sulge",
-    "Password protect" : "Parooliga kaitsmine",
     "Lost connection to signaling server. Try to reload the page manually." : "Kadus ühendus kõnehõlbustusserveriga. Proovi, kas lehe uuesti laadimine aitab.",
-    "Signaling servers" : "Kõnehõlbustusserverid"
+    "Invite all users and emails" : "Kutsu kõiki kasutajaid ja e-posti aadresse"
 },
 "nplurals=2; plural=(n != 1);");
