@@ -191,15 +191,13 @@ OC.L10N.register(
     "Call in progress" : "Puhelu meneillään",
     "You were mentioned" : "Sinut mainittiin",
     "Write to conversation" : "Kirjoita keskusteluun",
-    "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
-    "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
     "Conversation invitation" : "Keskustelukutsu",
-    "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
-    "Join »%s«" : "Liity »%s«",
+    "Description" : "Kuvaus",
     "You can also dial-in via phone with the following details" : "Voit myös yhdistää puhelimella seuraavin tiedoin",
     "Dial-in information" : "Puhelintiedot",
     "Meeting ID" : "Tapaamisen tunniste",
     "Your PIN" : "PIN-koodisi",
+    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "Password request: %s" : "Salasanapyyntö: %s",
     "Private conversation" : "Yksityinen keskustelu",
     "Deleted user (%s)" : "Poistettiin käyttäjä (%s)",
@@ -535,7 +533,6 @@ OC.L10N.register(
     "Bots settings" : "Bottien asetukset",
     "State" : "Tila",
     "Name" : "Nimi",
-    "Description" : "Kuvaus",
     "Last error" : "Viimeisin virhe",
     "Total errors count" : "Virheitä yhteensä",
     "Find more bots" : "Etsi lisää botteja",
@@ -1305,31 +1302,17 @@ OC.L10N.register(
     "Reports" : "Raportit",
     "Call summary" : "Puhelun yhteenveto",
     "Call summary - {title}" : "Puhelun yhteenveto - {title}",
-    "There are currently no commands available." : "Tällä hetkellä ei komentoja käytettävissä.",
-    "The command does not exist" : "Komentoa ei ole olemassa",
     "You tried to call {user}" : "Yritit soittaa käyttäjälle {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Puhelu %n vieraan kanssa (Kesto {duration})","Puhelu %n vieraan kanssa (Kesto {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Puhelu käyttäjien {user1} ja {user2} kesken (Kesto {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2} ja {user3} kesken (Kesto {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kesken (Kesto {duration})",
+    "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
+    "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
+    "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
+    "Join »%s«" : "Liity »%s«",
     "{user} invited you to a private conversation" : "{user} kutsui sinut yksityiskeskusteluun",
-    "Moderators" : "Moderaattorit",
-    "Commands" : "Komennot",
-    "Command" : "Komento",
-    "The message could not be sent" : "Viestiä ei voitu lähettää",
     "Copy conversation link" : "Kopioi keskustelulinkki",
-    "Loading" : "Ladataan",
     "Close" : "Sulje",
-    "Password protect" : "Suojaa salasanalla",
-    "Private poll" : "Yksityinen kysely",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk päivitettiin, lataa sivu uudelleen",
-    "Post to conversation" : "Lähetä keskusteluun",
-    "Share to conversation" : "Jaa keskusteluun",
     "An error happened when trying to share your file" : "Virhe yrittäessä jakaa tiedostoasi",
     "Failed to join the conversation. Try to reload the page." : "Liittyminen keskusteluun epäonnistui. Päivitä sivu.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud on huoltotilassa, päivitä sivu",
-    "TURN server" : "TURN-palvelin",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-palvelinta käytetään liikenteen välittämisessä palomuurin takana oleville osallistujille."
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud on huoltotilassa, päivitä sivu"
 },
 "nplurals=2; plural=(n != 1);");
