@@ -162,11 +162,8 @@ OC.L10N.register(
     "You were mentioned" : "Spomenuti ste",
     "Write to conversation" : "Napiši u razgovor",
     "Writes event information into a conversation of your choice" : "Upisuje informacije o događaju u željeni razgovor",
-    "%s invited you to a conversation." : "%s vas je pozvao u razgovor.",
-    "You were invited to a conversation." : "Pozvani ste u razgovor.",
     "Conversation invitation" : "Poziv u razgovor",
-    "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
-    "Join »%s«" : "Pridruži se »%s«",
+    "Description" : "Opis",
     "You can also dial-in via phone with the following details" : "Također se možete povezati putem telefona sa sljedećim podacima",
     "Dial-in information" : "Podaci za povezivanje putem telefona",
     "Meeting ID" : "ID sastanka",
@@ -197,9 +194,8 @@ OC.L10N.register(
     "{guest} (guest) mentioned you in conversation {call}" : "(gost) {guest} vas je spomenuo u razgovoru {call}",
     "A guest mentioned you in conversation {call}" : "Gost vas je spomenuo u razgovoru {call}",
     "View chat" : "Prikaži razmjenu poruka",
-    "{user} invited you to a private conversation" : "{user} vas je pozvao u privatni razgovor",
-    "Join call" : "Pridruži se pozivu",
     "{user} invited you to a group conversation: {call}" : "{user} vas je pozvao u grupni razgovor: {call}",
+    "Join call" : "Pridruži se pozivu",
     "Answer call" : "Odgovori na poziv",
     "{user} would like to talk with you" : "{user} želi razgovarati s vama",
     "Call back" : "Nazovi natrag",
@@ -536,7 +532,6 @@ OC.L10N.register(
     "Disabled" : "Onemogućeno",
     "State" : "Stanje",
     "Name" : "Naziv",
-    "Description" : "Opis",
     "Beta" : "Beta",
     "Permissions" : "Dopuštenja",
     "All messages" : "Sve poruke",
@@ -732,6 +727,8 @@ OC.L10N.register(
     "SIP dial-in is now disabled" : "Povezivanje putem SIP-a je onemogućeno",
     "Error occurred when enabling SIP dial-in" : "Došlo je do pogreške pri omogućavanju povezivanja putem SIP-a",
     "Error occurred when disabling SIP dial-in" : "Došlo je do pogreške pri onemogućavanju povezivanja putem SIP-a",
+    "Error while creating the conversation" : "Pogreška pri stvaranju razgovora",
+    "Create conversation" : "Stvori razgovor",
     "Enter your name" : "Unesite svoje ime",
     "Log in" : "Prijavite se",
     "Mark as read" : "Označi kao pročitano",
@@ -802,9 +799,7 @@ OC.L10N.register(
     "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Nema poruka",
-    "Error while creating the conversation" : "Pogreška pri stvaranju razgovora",
     "Create a new group conversation" : "Stvori novi grupni razgovor",
-    "Create conversation" : "Stvori razgovor",
     "Add participants" : "Dodaj sudionike",
     "Allow guests to join via link" : "Dopusti pridruživanje gostiju putem pozivnice",
     "Enter password" : "Unesi zaporku",
@@ -1067,43 +1062,19 @@ OC.L10N.register(
     "__language_name__" : "Hrvatski",
     "Tasks" : "Zadaci",
     "Notes" : "Bilješke",
-    "There are currently no commands available." : "Trenutno nema dostupnih naredbi.",
-    "The command does not exist" : "Naredba ne postoji",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Došlo je do pogreške pri izvršenju naredbe. Zatražite od administratora da provjeri zapise.",
     "You tried to call {user}" : "Pokušali ste nazvati {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Poziv s %n gostom (trajanje {duration})","Poziv s %n gostiju (trajanje {duration})","Poziv s %n gostiju (trajanje {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Poziv u kojem sudjeluju {user1} i {user2} (trajanje {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Poziv u kojem sudjeluju {user1}, {user2} i {user3} (trajanje {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Poziv u kojem sudjeluju {user1}, {user2}, {user3} i {user4} (trajanje {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Poziv u kojem sudjeluju {user1}, {user2}, {user3}, {user4} i {user5} (trajanje {duration})",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Naredbe su nova beta značajka aplikacije Nextcloud Talk. Omogućuju vam pokretanje skripti na vašem Nextcloudovom poslužitelju. Možete ih definirati s pomoću sučelja naredbenog retka. Primjer skripte kalkulatora možete pronaći u našoj {linkstart}dokumentaciji{linkend}.",
-    "Moderators" : "Moderatori",
-    "Commands" : "Naredbe",
-    "Command" : "Naredba",
-    "Script" : "Skripta",
-    "Response to" : "Odgovor na",
-    "Enabled for" : "Omogućeno za",
-    "Hosted high-performance backend" : "Visokoučinkovit pozadinski sustav na poslužitelju",
-    "SIP configuration is only possible with a high-performance backend." : "Konfiguracija SIP-a može se uspostaviti samo uz visokoučinkovit pozadinski sustav.",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Vanjski signalni poslužitelj treba se upotrebljavati u većim instancama. Ostavite prazno ako želite upotrebljavati interni signalni poslužitelj.",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Preporučujemo da postavite distribuiranu predmemoriju za Nextcloud Talk zajedno s učinkovitim pozadinskim sustavom.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Ne upozoravaj na poteškoće s povezivanjem u pozivima s više od 4 sudionika",
+    "%s invited you to a conversation." : "%s vas je pozvao u razgovor.",
+    "You were invited to a conversation." : "Pozvani ste u razgovor.",
+    "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
+    "Join »%s«" : "Pridruži se »%s«",
+    "{user} invited you to a private conversation" : "{user} vas je pozvao u privatni razgovor",
     "Copy conversation link" : "Kopiraj poveznicu za razgovor",
-    "Channel ID or name" : "ID ili naziv kanala",
-    "Loading" : "Učitavanje",
     "Close" : "Zatvori",
-    "Password protect" : "Zaštita zaporkom",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu prije upućivanja ili pridruživanja razgovoru.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu",
-    "Post to conversation" : "Objavi u razgovoru",
     "An error happened when trying to share your file" : "Došlo je do pogreške pri pokušaju dijeljenja datoteke",
     "Failed to join the conversation. Try to reload the page." : "Pridruživanje razgovoru nije uspjelo. Pokušajte ponovno učitati stranicu.",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud je u načinu održavanja, ponovno učitajte stranicu",
-    "Lost connection to signaling server. Try to reload the page manually." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušajte ponovno učitati stranicu.",
-    "Specify commands the users can use in chats" : "Navedite naredbe koje korisnici mogu koristiti pri razmjeni poruka",
-    "TURN server" : "Poslužitelj TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Poslužitelj TURN upotrebljava se za usmjeravanje prometa sudionika iza vatrozida.",
-    "Signaling servers" : "Signalni poslužitelji",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Vanjski signalni poslužitelj može se upotrebljavati u većim instancama. Ostavite prazno ako želite upotrebljavati interni signalizacijski poslužitelj."
+    "Lost connection to signaling server. Try to reload the page manually." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušajte ponovno učitati stranicu."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
