@@ -67,11 +67,9 @@ OC.L10N.register(
     "Invalid image" : "Ógild mynd",
     "Unknown filetype" : "Óþekkt skráategund",
     "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
-    "%s invited you to a conversation." : "%s bauð þér að taka þátt í samtali.",
-    "You were invited to a conversation." : "Þér var boðið að taka þátt í samtali.",
     "Conversation invitation" : "Boð í samtal",
-    "Click the button below to join." : "Smelltu á hnappinn hér fyrir neðan til að taka þátt.",
-    "Join »%s«" : "Taka þátt í »%s«",
+    "Description" : "Lýsing",
+    "Talk conversation for event" : "Samtal fyrir atburð",
     "Password request: %s" : "Beiðni um lykilorð: %s",
     "Private conversation" : "Einkasamtal",
     "Deleted user (%s)" : "Eyddi notanda (%s)",
@@ -361,7 +359,6 @@ OC.L10N.register(
     "Disabled" : "Óvirkt",
     "State" : "Staða",
     "Name" : "Nafn",
-    "Description" : "Lýsing",
     "Beta" : "BETA-prófunarútgáfa",
     "Permissions" : "Heimildir",
     "All messages" : "Öll skilaboð",
@@ -597,27 +594,11 @@ OC.L10N.register(
     "__language_name__" : "Íslenska",
     "Tasks" : "Verkefni",
     "Notes" : "Minnispunktar",
-    "There are currently no commands available." : "Það eru engarskipanir tiltækar í augnablikinu.",
-    "The command does not exist" : "Skipunin er ekki til",
-    "Call with {user1} and {user2} (Duration {duration})" : "Samtal við {user1} og {user2} (tímalengd {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal við {user1}, {user2} og {user3} (tímalengd {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3} og {user4} (tímalengd {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3}, {user4} og {user5} (tímalengd {duration})",
+    "%s invited you to a conversation." : "%s bauð þér að taka þátt í samtali.",
+    "You were invited to a conversation." : "Þér var boðið að taka þátt í samtali.",
+    "Click the button below to join." : "Smelltu á hnappinn hér fyrir neðan til að taka þátt.",
+    "Join »%s«" : "Taka þátt í »%s«",
     "{user} invited you to a private conversation" : "{user} bauð þér að taka þátt í einkasímtali",
-    "Moderators" : "Umsjónarmenn",
-    "Commands" : "Skipanir",
-    "Command" : "Skipun",
-    "Script" : "Skrifta",
-    "Response to" : "Svar til",
-    "Enabled for" : "Virkjað fyrir",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
-    "Loading" : "Hleð inn",
-    "Close" : "Loka",
-    "Password protect" : "Verja með lykilorði",
-    "Specify commands the users can use in chats" : "Tilgreindu hvaða skipanir notendur geta notað í spjalli",
-    "TURN server" : "TURN-þjónn",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
-    "Signaling servers" : "Merkjasendingaþjónar",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn."
+    "Close" : "Loka"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
