@@ -160,11 +160,8 @@ OC.L10N.register(
     "You were mentioned" : "Jūs buvote paminėti",
     "Write to conversation" : "Rašyti į pokalbį",
     "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
-    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
-    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
     "Conversation invitation" : "Pakvietimas į pokalbį",
-    "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
-    "Join »%s«" : "Prisijungti prie »%s«",
+    "Description" : "Aprašas",
     "Meeting ID" : "Susitikimo ID",
     "Your PIN" : "Jūsų PIN kodas",
     "Password request: %s" : "Slaptažodžio prašymas: %s",
@@ -442,7 +439,6 @@ OC.L10N.register(
     "Disabled" : "Išjungta",
     "State" : "Būsena",
     "Name" : "Vardas",
-    "Description" : "Aprašas",
     "Last error" : "Paskutinė klaida",
     "Total errors count" : "Bendras klaidų skaičius",
     "Beta" : "Beta",
@@ -952,36 +948,18 @@ OC.L10N.register(
     "__language_name__" : "Lietuvių",
     "Tasks" : "Užduotys",
     "Notes" : "Užrašai",
-    "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
-    "The command does not exist" : "Komandos nėra",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Vykdant komandą, įvyko klaida. Paprašykite administratoriaus, kad patikrintų žurnalus.",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Skambutis su %n svečiu (Trukmė {duration})","Skambutis su %n svečiais (Trukmė {duration})","Skambutis su %n svečių (Trukmė {duration})","Skambutis %n svečiu (Trukmė {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Skambutis su {user1} ir {user2} (Trukmė {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Skambutis su {user1}, {user2} ir {user3} (Trukmė {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3} ir {user4} (Trukmė {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3}, {user4} ir {user5} (Trukmė {duration})",
+    "%s invited you to a conversation." : "%s jus pakvietė į pokalbį.",
+    "You were invited to a conversation." : "Jūs buvote pakviesti į pokalbį.",
+    "Click the button below to join." : "Norėdami prisijungti, spustelėkite mygtuką žemiau.",
+    "Join »%s«" : "Prisijungti prie »%s«",
     "{user} invited you to a private conversation" : "{user} jus pakvietė į privatų pokalbį",
-    "Moderators" : "Moderatoriai",
-    "Commands" : "Komandos",
-    "Command" : "Komanda",
-    "Script" : "Scenarijus",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai turėtų būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Neįspėti apie jungiamumo problemas skambučiuose su daugiau kaip 4 dalyviais",
-    "The message could not be sent" : "Nepavyko išsiųsti žinutės",
+    "Please try to reload the page" : "Pabandykite įkelti puslapį iš naujo",
     "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
-    "Channel ID or name" : "Kanalo ID ar pavadinimas",
-    "Loading" : "Įkeliama",
     "Close" : "Užverti",
-    "Password protect" : "Apsaugoti slaptažodžiu",
-    "Private poll" : "Privati apklausa",
+    "Next call" : "Kitas skambutis",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
     "An error happened when trying to share your file" : "Bandant bendrinti jūsų failą įvyko klaida",
     "Failed to join the conversation. Try to reload the page." : "Nepavyko prisijungti prie pokalbio. Pabandykite įkelti puslapį iš naujo.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
-    "TURN server" : "TURN serveris",
-    "Signaling servers" : "Signaliniai serveriai",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai gali būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
-    "Please try to reload the page" : "Pabandykite įkelti puslapį iš naujo",
-    "Next call" : "Kitas skambutis"
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
