@@ -72,11 +72,8 @@ OC.L10N.register(
     "More conversations" : "Vairāk sarunu",
     "Say hi to your friends and colleagues!" : "Sasveicinies ar saviem draugiem un kolēģiem!",
     "No unread mentions" : "Nav nelasītu pieminēšanu",
-    "%s invited you to a conversation." : "%s uzaicināja jūs uz sarunu.",
-    "You were invited to a conversation." : "Jūs uzaicinājāt uz sarunu.",
     "Conversation invitation" : "Sarunas uzaicinājums",
-    "Click the button below to join." : "Noklikšķiniet uz tālāk esošās pogas, lai pievienotos.",
-    "Join »%s«" : "Pievienoties »%s«",
+    "Description" : "Apraksts",
     "Password request: %s" : "Paroles pieprasījums: %s",
     "Private conversation" : "Privāta saruna",
     "Dismiss notification" : "Noraidīt paziņojumu",
@@ -353,7 +350,6 @@ OC.L10N.register(
     "Disabled" : "Atspējots",
     "State" : "Stāvoklis",
     "Name" : "Nosaukums",
-    "Description" : "Apraksts",
     "Beta" : "Beta",
     "Permissions" : "Atļaujas",
     "General settings" : "Vispārīgie iestatījumi",
@@ -365,7 +361,7 @@ OC.L10N.register(
     "Status" : "Status",
     "Created at" : "Izveidots plkst.",
     "Validate SSL certificate" : "Pārbaudīt SSL sertifikātu",
-    "Delete this server" : "Dzēst šo serveri",
+    "Delete this server" : "Izdzēst šo serveri",
     "Test this server" : "Testēt šo serveri",
     "Shared secret" : "Koplietojams noslēpums",
     "STUN server URL" : "STUN servera URL",
@@ -417,11 +413,11 @@ OC.L10N.register(
     "Leave conversation" : "Atstāt sarunu",
     "No" : "Nē",
     "Yes" : "Jā",
-    "Delete conversation" : "Dzēst sarunu",
+    "Delete conversation" : "Izdzēst sarunu",
     "Password protection" : "Password protection",
     "Open conversation" : "Atvērt sarunu",
     "Edit" : "Labot",
-    "Delete" : "Dzēst",
+    "Delete" : "Izdzēst",
     "Notifications" : "Paziņojumi",
     "Log in" : "Pieteikties",
     "Remove from favorites" : "Noņemt no izlases",
@@ -498,6 +494,7 @@ OC.L10N.register(
     "Login" : "Autorizēties",
     "Nickname" : "Iesauka",
     "Client ID" : "Klienta ID",
+    "Polls" : "Aptaujas",
     "Audio" : "Audio",
     "Other" : "Cits",
     "Group" : "Grupa",
@@ -521,28 +518,11 @@ OC.L10N.register(
     "Tasks" : "Uzdevumi",
     "Notes" : "Piezīmes",
     "Reports" : "Atskaites",
-    "There are currently no commands available." : "Pašlaik nav pieejamas komandas.",
-    "The command does not exist" : "Šī komanda nepastāv",
-    "Call with {user1} and {user2} (Duration {duration})" : "Saruna ar {user1} un {user2} ( Ilgums {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Saruna ar {user1}, {user2} un {user3} ( Ilgums {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3} un {user4} ( Ilgums {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3}, {user4} un {user5} ( Ilgums {duration})",
+    "%s invited you to a conversation." : "%s uzaicināja jūs uz sarunu.",
+    "You were invited to a conversation." : "Jūs uzaicinājāt uz sarunu.",
+    "Click the button below to join." : "Noklikšķiniet uz tālāk esošās pogas, lai pievienotos.",
+    "Join »%s«" : "Pievienoties »%s«",
     "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
-    "Moderators" : "Regulētāji",
-    "Commands" : "Komandas",
-    "Command" : "Komanda",
-    "Script" : "Skripts",
-    "Response to" : "Atbilde uz",
-    "Enabled for" : "Iespējots",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Lielāka izmēra instalācijām pēc izvēles jāizmanto ārējais signalizēšanas serveris. Atstājiet tukšu, lai izmantotu iekšējo signalizēšanas serveri.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Nebrīdināt par savienojamības problēmām zvanos ar vairāk nekā 4 dalībniekiem",
-    "Loading" : "Ielādē",
-    "Close" : "Aizvērt",
-    "Password protect" : "Aizsargāt ar paroli",
-    "Specify commands the users can use in chats" : "Komandu norādīšana, kuras lietotāji var izmantot tērzēšanā",
-    "TURN server" : "TURN serveris",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveris tiek izmantots, lai bloķētu dalībnieku datplūsmu aiz ugunsmūra.",
-    "Signaling servers" : "Signalizēšanas serveri",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ārējo signalizēšanas serveri var pēc izvēles izmantot lielākām instalācijām. Atstājiet tukšu, lai izmantotu iekšējo signalizēšanas serveri."
+    "Close" : "Aizvērt"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
