@@ -155,11 +155,8 @@ OC.L10N.register(
     "You were mentioned" : "Споменати сте",
     "Write to conversation" : "Пишивајте во разговорот",
     "Writes event information into a conversation of your choice" : "Напишете информации за настанот во разговорот по ваш избор",
-    "%s invited you to a conversation." : "%s ве покани на разговор.",
-    "You were invited to a conversation." : "Поканети сте на разговор.",
     "Conversation invitation" : "Покана за разговор",
-    "Click the button below to join." : "Кликнете на копчето подолу за да се приклучите.",
-    "Join »%s«" : "Приклучете се »%s«",
+    "Description" : "Опис",
     "You can also dial-in via phone with the following details" : "Истотака можете да се приклучите преку телефон со следниве детали",
     "Dial-in information" : "Информации",
     "Meeting ID" : "ID на средба",
@@ -524,7 +521,6 @@ OC.L10N.register(
     "Disabled" : "Оневозможен",
     "State" : "Статус",
     "Name" : "Име",
-    "Description" : "Опис",
     "Last error" : "Последна грешка",
     "Beta" : "Бета",
     "Permissions" : "Дозволи",
@@ -1002,35 +998,18 @@ OC.L10N.register(
     "iOS app" : "iOS апликација",
     "__language_name__" : "Македонски",
     "Tasks" : "Задачи",
-    "There are currently no commands available." : "Моментално нема достапни команди.",
-    "The command does not exist" : "Комендата не постои",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Настана грешка при стартување на командата. Контактирајте го администраторот.",
     "You tried to call {user}" : "Се обидовте да го повикате {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Повик со %n гостин (Времетраење {duration})","Повик со %n гости (Времетраење {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Повик со {user1} и {user2} (Времетраење {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "повик со {user1}, {user2} и {user3} (Времетраење {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Повик со {user1}, {user2}, {user3} и {user4} (Времетраење {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Повик со {user1}, {user2}, {user3}, {user4} и {user5} (Времетраење {duration})",
+    "%s invited you to a conversation." : "%s ве покани на разговор.",
+    "You were invited to a conversation." : "Поканети сте на разговор.",
+    "Click the button below to join." : "Кликнете на копчето подолу за да се приклучите.",
+    "Join »%s«" : "Приклучете се »%s«",
     "{user} invited you to a private conversation" : "{user} те покани на приватен разговор",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Командите се нова бета опција во Nextcloud Talk. Тие ви дозволуваат да извршувате скрипти на вашиот сервер Nextcloud. Можете да ги дефинирате со нашиот интерфејс на командната линија. Пример за скрипта на калкулатор може да се најде во нашата {linkstart}документација{linkend}.",
-    "Moderators" : "Модератори",
-    "Commands" : "Команди",
-    "Command" : "Команда",
-    "Script" : "Скрипта",
-    "Response to" : "Одговори на",
-    "Enabled for" : "Овозможено за",
     "Copy conversation link" : "копирај линк од разговорот",
-    "Loading" : "Се вчитува",
     "Close" : "Затвори",
-    "Password protect" : "Заштити со лозинка",
-    "Private poll" : "Приватна анкета",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Разговорот беше ажуриран, треба повторно да ја вчитате страницата пред да започнете или да се придружите на повик.",
     "Nextcloud Talk was updated, please reload the page" : "Разговорот е ажуриран, повторно вчитајте ја страната",
-    "Post to conversation" : "Објава во разговор",
-    "Share to conversation" : "Споделено во разговор",
     "An error happened when trying to share your file" : "Се случи грешка при обидот за споделување на датотека",
     "Failed to join the conversation. Try to reload the page." : "Неуспешно приклучување кон разговорот, Пробајте да ја превчитате страницата.",
-    "Nextcloud is in maintenance mode, please reload the page" : "Активиран е мод за одржавање, превчитајте ја страницата",
-    "TURN server" : "TURN сервер"
+    "Nextcloud is in maintenance mode, please reload the page" : "Активиран е мод за одржавање, превчитајте ја страницата"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
