@@ -167,11 +167,8 @@ OC.L10N.register(
     "Call in progress" : "Sonada en cors",
     "You were mentioned" : "Qualqu’un vos a mencionat",
     "Write to conversation" : "Escriure dins la conversacion",
-    "%s invited you to a conversation." : "%s vos a convidat a una conversacion.",
-    "You were invited to a conversation." : "Òm vos a convidat a una conversacion.",
     "Conversation invitation" : "Convit de conversacion",
-    "Click the button below to join." : "Clicatz sul boton per participar.",
-    "Join »%s«" : "Rejónher « %s »",
+    "Description" : "Descripcion",
     "Dial-in information" : "Entresenhas de sonada",
     "Meeting ID" : "Identificant reünion",
     "Your PIN" : "Vòstre còdi",
@@ -530,7 +527,6 @@ OC.L10N.register(
     "Enabled" : "Activada",
     "Disabled" : "Desactivat",
     "Name" : "Nom",
-    "Description" : "Descripcion",
     "Beta" : "Bèta",
     "Permissions" : "Autorizacions",
     "All messages" : "Totes los messatges",
@@ -1102,43 +1098,19 @@ OC.L10N.register(
     "iOS app" : "Aplicacion iOS",
     "__language_name__" : "Occitan",
     "Tasks" : "Prètzfaches",
-    "There are currently no commands available." : "Cap de comanda pas disponibla pel moment.",
-    "The command does not exist" : "La comanda existís pas",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Una error s’es producha en executant la comanda. Volgatz demandar a l’administrator de verificar los jornals.",
     "You tried to call {user}" : "Avètz ensajat de sonar {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
+    "%s invited you to a conversation." : "%s vos a convidat a una conversacion.",
+    "You were invited to a conversation." : "Òm vos a convidat a una conversacion.",
+    "Click the button below to join." : "Clicatz sul boton per participar.",
+    "Join »%s«" : "Rejónher « %s »",
     "{user} invited you to a private conversation" : "{user} vos a convidat a una conversacion privada",
-    "Moderators" : "Moderators",
-    "Commands" : "Comandas",
-    "Command" : "Comanda",
-    "Script" : "Escript",
-    "Response to" : "Respondre a",
-    "Enabled for" : "Activat per",
-    "SIP configuration is only possible with a high-performance backend." : "La configuracion SIP es sonque possibla amb un backend de nauta performança",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Es forçadament recomandat de configurar a cache distribuit pendent l’utilizacion de Nextcloud Talk amb un back-end de fòrt rendiment.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Avertir pas dels problèmas de connectivitat dins las sonadas de mai de 4 participants",
-    "The message could not be sent" : "Se podiá pas enviar lo messatge",
     "Copy conversation link" : "Copiar lo ligam de conversacion",
-    "Channel ID or name" : "ID o nom del canal",
-    "Loading" : "Loading",
     "Close" : "Tampar",
-    "Password protect" : "Protegir per un senhal",
-    "Private poll" : "Sondatge privat",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk foguèt mes a jorn, mercés de tornar cargar la pagina",
-    "Post to conversation" : "Publicar a la conversacion",
-    "Share to conversation" : "Partejar dins una conversacion",
     "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
     "Failed to join the conversation. Try to reload the page." : "Impossible de rejónher la conversacion. Ensajatz de recargar la pagina.",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud es en mòde manteniment, volgatz recargar la pagina",
-    "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament.",
-    "Specify commands the users can use in chats" : "Indicar las comandas que los utilizaires pòdon utilizar als chats",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Lo servidor TURN es utilizat per desviar lo trafic dels participants darrièr un parafuòc.",
-    "Signaling servers" : "Servidors de senhalizacion"
+    "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament."
 },
 "nplurals=2; plural=(n > 1);");
