@@ -136,11 +136,8 @@ OC.L10N.register(
     "Call in progress" : "Videoconferință în curs",
     "You were mentioned" : "Ați fost menționat",
     "Write to conversation" : "Postați în conversație",
-    "%s invited you to a conversation." : "%s v-a invitat într-o conversație.",
-    "You were invited to a conversation." : "Ați fost invitat într-o conversație.",
     "Conversation invitation" : "Invitație în conversație",
-    "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
-    "Join »%s«" : "Alăturați-vă »%s«",
+    "Description" : "Descriere",
     "Meeting ID" : "ID întâlnire",
     "Password request: %s" : "Solicitare parolă: %s",
     "Private conversation" : "Conversație privată",
@@ -461,7 +458,6 @@ OC.L10N.register(
     "Disabled" : "Dezactivați",
     "State" : "Stadiu",
     "Name" : "Nume",
-    "Description" : "Descriere",
     "Last error" : "Ultima eroare",
     "Total errors count" : "Total erori",
     "Beta" : "Beta",
@@ -886,21 +882,13 @@ OC.L10N.register(
     "Tasks" : "Sarcini",
     "Notes" : "Notițe",
     "You tried to call {user}" : "Ați încercat să apelați pe {user}",
-    "Call with {user1} and {user2} (Duration {duration})" : "Apel cu {user1} și {user2} (Durată {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Apelul cu {user1}, {user2} și {user3} (Durată {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3} și {user4} (Durată {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Apel cu {user1}, {user2}, {user3}, {user4} și {user5} (Durată {duration})",
+    "%s invited you to a conversation." : "%s v-a invitat într-o conversație.",
+    "You were invited to a conversation." : "Ați fost invitat într-o conversație.",
+    "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
+    "Join »%s«" : "Alăturați-vă »%s«",
     "{user} invited you to a private conversation" : "{user} v-a invitat într-o conversație privată",
-    "Moderators" : "Moderatori",
-    "Response to" : "Răspuns la",
-    "Enabled for" : "Activat pentru",
-    "The message could not be sent" : "Mesajul nu s-a putut transmite ",
     "Copy conversation link" : "Copiază linkul conversației",
-    "Loading" : "Loading",
     "Close" : "Închide",
-    "Password protect" : "Protejare cu parolă",
-    "Post to conversation" : "Postare în conversație",
-    "Share to conversation" : "Partajare la conversație",
     "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
     "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. "
 },
