@@ -155,11 +155,8 @@ OC.L10N.register(
     "You were mentioned" : "Ses istadu mentovadu",
     "Write to conversation" : "Iscrie in sa resonada",
     "Writes event information into a conversation of your choice" : "Iscriet is informatziones de s'eventu in una resonada de sèberu tuo",
-    "%s invited you to a conversation." : "%s t'at invitadu in una resonada",
-    "You were invited to a conversation." : "T'ant invitadu in una resonada.",
     "Conversation invitation" : "Cumbidu a sa resonada",
-    "Click the button below to join." : "Incarca su butone a suta pro intrare.",
-    "Join »%s«" : "Intra in »%s«",
+    "Description" : "Descritzione",
     "You can also dial-in via phone with the following details" : "Ti podes connètere puru cun su telèfono cun is detàllios in fatu",
     "Dial-in information" : "Informatziones de connessione",
     "Meeting ID" : "ID de s'atòbiu",
@@ -190,9 +187,8 @@ OC.L10N.register(
     "{guest} (guest) mentioned you in conversation {call}" : "{guest} (utèntzia istràngia) t'at mentovadu in sa resonada {call}",
     "A guest mentioned you in conversation {call}" : "Un'utèntzia istràngia t'at mentovadu in sa resonada {call}",
     "View chat" : "Visualiza sa tzarrada",
-    "{user} invited you to a private conversation" : "{user} t'at invitadu in una resonada privada",
-    "Join call" : "Intra in sa mutida",
     "{user} invited you to a group conversation: {call}" : "{user} t'at invitadu a una resonada de grupu: {call}",
+    "Join call" : "Intra in sa mutida",
     "Answer call" : "Responde a sa mutida",
     "{user} would like to talk with you" : "{user} diat bòlere faeddare cun tue",
     "Call back" : "Torra a mutire",
@@ -528,7 +524,6 @@ OC.L10N.register(
     "Disabled" : "Disabilitada",
     "State" : "Istadu",
     "Name" : "Nùmene",
-    "Description" : "Descritzione",
     "Beta" : "Beta",
     "Permissions" : "Permissos",
     "All messages" : "Totu is messàgios",
@@ -719,6 +714,8 @@ OC.L10N.register(
     "SIP dial-in is now disabled" : "S'atzessu SIP immoe est disativu",
     "Error occurred when enabling SIP dial-in" : "B'at àpidu un'errore ativende s'atzessu SIP",
     "Error occurred when disabling SIP dial-in" : "B'at àpidu un'errore disativende s'atzessu SIP",
+    "Error while creating the conversation" : "Errore creende sa resonada ",
+    "Create conversation" : "Crea resonada",
     "Enter your name" : "Inserta•nche su nùmene tuo",
     "Log in" : "Intra",
     "Mark as read" : "Marca comente lèghidu",
@@ -727,6 +724,7 @@ OC.L10N.register(
     "Add to favorites" : "Agiunghe a preferidos",
     "You need to promote a new moderator before you can leave the conversation." : "Depes promòvere un'àtera persona chi moderet antis de lassare sa resonada.",
     "Conversation actions" : "Atziones de is resonadas",
+    "Unread" : "De lèghere",
     "No matches found" : "Peruna currispondèntzia agatada",
     "No conversations found" : "Peruna resonada agatada",
     "An error occurred while performing the search" : "B'at àpidu un'errore in sa chirca",
@@ -797,9 +795,7 @@ OC.L10N.register(
     "_%n day ago_::_%n days ago_" : ["%n dies a oe","%n dies a oe"],
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Perunu messàgiu",
-    "Error while creating the conversation" : "Errore creende sa resonada ",
     "Create a new group conversation" : "Crea unu grupu de resonada nou",
-    "Create conversation" : "Crea resonada",
     "Add participants" : "Agiunghe partetzipantes",
     "Allow guests to join via link" : "Permite a is persones invitadas de intrare cun unu ligòngiu",
     "Enter password" : "Inserta crae",
@@ -1046,43 +1042,19 @@ OC.L10N.register(
     "__language_name__" : "sardu",
     "Tasks" : "Fainas",
     "Notes" : "Notas",
-    "There are currently no commands available." : "No b'at cummandos disponìbiles in custu momentu.",
-    "The command does not exist" : "Su cummandu no esistit",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "B'at àpidu un'errore in s'esecutzione de su cummandu. Pedi a chie amministrat de castiare is registros.",
     "You tried to call {user}" : "As proadu a tzerriare a {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Mutida cun %n persones istràngias (Durada {durada})","Mutida cun %n persones istràngias (Durada {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Mutida cun {user2} e {user2} (Durada {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Mutida cun {user1}, {user2} e {user3} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Mutida cun {user1}, {user2}, {user3} e {user4} (Durada {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Mutida cun {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Is cummandos sunt una funtzionalidade noa in Nextcloud Talk. Ti permitint de eseguire script in su serbidore Nextcloud. Ddus podes definire cun s'interfache a lìnia de cumandu. Un'esèmpiu de script de calculadora si podet agatare in sa {linkstart}documentatzione{linkend}.",
-    "Moderators" : "Is chi moderant",
-    "Commands" : "Cumandos",
-    "Command" : "Cumandu",
-    "Script" : "Script",
-    "Response to" : "Risposta a ",
-    "Enabled for" : "Ativadu pro",
-    "Hosted high-performance backend" : "Motore de prestatziones artas retzidu.",
-    "SIP configuration is only possible with a high-performance backend." : "Sa cunfiguratzione SiP est possìbile isceti cun unu motore de prestatziones artas.",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Pro installatziones mannas, si diat dèpere seberare unu serbidore de signalatzione de foras. Lassa bòidu pro impreare unu serbidore de signalatzione de intro.",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Cussigiamus de cunfigurare una memòria temporànea distribuida cando impreas Nextcloud Talk cun unu Motore de Prestatziones Artas.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Non mi signales problemas de connetividade in is mutidas cun prus de 4 persones",
+    "%s invited you to a conversation." : "%s t'at invitadu in una resonada",
+    "You were invited to a conversation." : "T'ant invitadu in una resonada.",
+    "Click the button below to join." : "Incarca su butone a suta pro intrare.",
+    "Join »%s«" : "Intra in »%s«",
+    "{user} invited you to a private conversation" : "{user} t'at invitadu in una resonada privada",
     "Copy conversation link" : "Còpia su ligòngiu de sa resonada",
-    "Channel ID or name" : "ID o nùmene de su canale",
-    "Loading" : "Carrighende",
     "Close" : "Serra",
-    "Password protect" : "Bàrdia sa crae",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk est istadu agiornadu, depes torrare a carrigare sa pàgina antis de pòdere cumintzare o intrare in una mutida.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud est istadu agiornadu, torra a carrigare sa pàgina",
-    "Post to conversation" : "Pùblica in sa resonada",
     "An error happened when trying to share your file" : "B'at àpidu un'errore proende a cumpartzire s'archìviu",
     "Failed to join the conversation. Try to reload the page." : "No at fatu a intrare in sa resonada. Proa a torrare a carrigare sa pàgina.",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud est in mantenidura, torra a carrigare sa pàgina",
-    "Lost connection to signaling server. Try to reload the page manually." : "Connessione pèrdida cun su serbidore de signalatzione. Proa a torrare a carrigare sa pàgina a manu.",
-    "Specify commands the users can use in chats" : "Ispetzìfica is commandos chi is utentes podent impreare in sa tzarrada",
-    "TURN server" : "Serbidore TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN s'impreat pro imbiare su tràficu dae is partetzipantes a secus de unu firewall.",
-    "Signaling servers" : "Serbidores de signalatzione",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Unu serbidore de signalatzione de foras podet èssere impreadu a sèberu pro installatziones prus mannas. Lassa bòidu pro impreare unu serbidore de signalatzione de intro."
+    "Lost connection to signaling server. Try to reload the page manually." : "Connessione pèrdida cun su serbidore de signalatzione. Proa a torrare a carrigare sa pàgina a manu."
 },
 "nplurals=2; plural=(n != 1);");
