@@ -152,11 +152,8 @@ OC.L10N.register(
     "You were mentioned" : "Bạn đã được nhắc tới",
     "Write to conversation" : "Viết vào cuộc trò chuyên",
     "Writes event information into a conversation of your choice" : "Viết thông tin sự kiện vào một cuộc trò chuyện bạn chọn",
-    "%s invited you to a conversation." : "%s đã được mời vào cuộc trò chuyện",
-    "You were invited to a conversation." : "Bạn đã được mời vào cuộc trò chuyện",
     "Conversation invitation" : "Lời mời vào cuộc trò chuyện",
-    "Click the button below to join." : "Click vào nút bên dưới để tham gia",
-    "Join »%s«" : "Tham gia »%s«",
+    "Description" : "Mô tả",
     "You can also dial-in via phone with the following details" : "Bạn cũng có thể quay số qua điện thoại với các thông tin chi tiết sau",
     "Dial-in information" : "Thông tin quay số",
     "Meeting ID" : "Id cuộc họp",
@@ -271,7 +268,6 @@ OC.L10N.register(
     "Disabled" : "Tắt",
     "State" : "Trạng thái",
     "Name" : "Tên",
-    "Description" : "Mô tả",
     "All messages" : "Tất cả tin nhắn",
     "Off" : "Tắt",
     "General settings" : "Cài đặt chung",
@@ -713,42 +709,18 @@ OC.L10N.register(
     "__language_name__" : "Tiếng Việt",
     "Tasks" : "Nhiệm vụ",
     "Notes" : "Ghi chú",
-    "There are currently no commands available." : "Hiện tại không có lệnh nào khả dụng.",
-    "The command does not exist" : "Lệnh không tồn tại",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Đã xảy ra lỗi khi chạy lệnh. Vui lòng yêu cầu quản trị viên kiểm tra nhật ký.",
     "You tried to call {user}" : "Bạn đã cố gắng gọi {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Gọi với %n khách (Thời hạn {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Đã gọi với {user1} và {user2} (Thời lượng {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Đã gọi với {user1}, {user2} và {user3} (Thời lượng {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Đã gọi với {user1}, {user2}, {user3} và {user4} (Thời lượng {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Đã gọi với {user1}, {user2}, {user3}, {user4} và {user5} (Thời lượng {duration})",
+    "%s invited you to a conversation." : "%s đã được mời vào cuộc trò chuyện",
+    "You were invited to a conversation." : "Bạn đã được mời vào cuộc trò chuyện",
+    "Click the button below to join." : "Click vào nút bên dưới để tham gia",
+    "Join »%s«" : "Tham gia »%s«",
     "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Lệnh là một tính năng beta mới trong vWorkspace Talk. Chúng cho phép bạn chạy các tập lệnh trên máy chủ vWorkspace của bạn. Bạn có thể xác định chúng bằng giao diện dòng lệnh của chúng tôi. Có thể tìm thấy ví dụ về tập lệnh máy tính trong {linkstart} tài liệu {linkend} của chúng tôi.",
-    "Moderators" : "Người kiểm duyệt",
-    "Commands" : "Lệnh",
-    "Command" : "Lệnh",
-    "Response to" : "Phản hồi với",
-    "Enabled for" : "Đã bật cho",
-    "Hosted high-performance backend" : "Backend hiệu suất cao",
-    "SIP configuration is only possible with a high-performance backend." : "Cấu hình SIP chỉ có thể thực hiện được với phần backend hiệu suất cao.",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài nên được tùy chọn sử dụng cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ.",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Chúng tôi khuyên bạn nên thiết lập bộ nhớ đệm phân tán khi sử dụng vWorkspace Talk cùng với Back-end hiệu suất cao.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Không cảnh báo về sự cố kết nối trong cuộc gọi có hơn 4 người tham gia",
     "Copy conversation link" : "Sao chép liên kết cuộc trò chuyện",
-    "Channel ID or name" : "ID hoặc tên kênh",
-    "Loading" : "Đang tải",
     "Close" : "Đóng",
-    "Password protect" : "Mật khẩu bảo vệ",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "vWorkspace Talk đã được cập nhật, bạn cần tải lại trang trước khi có thể bắt đầu hoặc tham gia cuộc gọi.",
     "Nextcloud Talk was updated, please reload the page" : "vWorkspace Talk đã được cập nhật, vui lòng tải lại trang",
-    "Post to conversation" : "Đăng lên cuộc trò chuyện",
     "Failed to join the conversation. Try to reload the page." : "Không tham gia được cuộc trò chuyện. Hãy thử tải lại trang.",
     "Nextcloud is in maintenance mode, please reload the page" : "vWorkspace đang ở chế độ bảo trì, vui lòng tải lại trang",
-    "Lost connection to signaling server. Try to reload the page manually." : "Mất kết nối với máy chủ báo hiệu. Cố gắng tải lại trang theo cách thủ công.",
-    "Specify commands the users can use in chats" : "Chỉ định các lệnh mà người dùng có thể sử dụng trong các cuộc trò chuyện",
-    "TURN server" : "Máy chủ TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Máy chủ TURN được sử dụng để ủy quyền lưu lượng truy cập từ những người tham gia đằng sau tường lửa.",
-    "Signaling servers" : "Máy chủ báo hiệu",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài có thể được sử dụng tùy chọn cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ."
+    "Lost connection to signaling server. Try to reload the page manually." : "Mất kết nối với máy chủ báo hiệu. Cố gắng tải lại trang theo cách thủ công."
 },
 "nplurals=1; plural=0;");
