@@ -2,84 +2,61 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2021 Vitor Mattos <vitor@php.rio>
- *
- * @author Vitor Mattos <vitor@php.rio>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Chat;
 
+use OCA\Talk\Events\BeforeReactionAddedEvent;
+use OCA\Talk\Events\BeforeReactionRemovedEvent;
+use OCA\Talk\Events\ReactionAddedEvent;
+use OCA\Talk\Events\ReactionRemovedEvent;
 use OCA\Talk\Exceptions\ReactionAlreadyExistsException;
 use OCA\Talk\Exceptions\ReactionNotSupportedException;
 use OCA\Talk\Exceptions\ReactionOutOfContextException;
 use OCA\Talk\Participant;
+use OCA\Talk\ResponseDefinitions;
 use OCA\Talk\Room;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\Comments\NotFoundException;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IL10N;
+use OCP\PreConditionNotMetException;
 
+/**
+ * @psalm-import-type TalkReaction from ResponseDefinitions
+ */
 class ReactionManager {
-	private ChatManager $chatManager;
-	private CommentsManager $commentsManager;
-	private IL10N $l;
-	private MessageParser $messageParser;
-	private Notifier $notifier;
-	protected ITimeFactory $timeFactory;
 
 	public function __construct(
-		ChatManager $chatManager,
-		CommentsManager $commentsManager,
-		IL10N $l,
-		MessageParser $messageParser,
-		Notifier $notifier,
-		ITimeFactory $timeFactory,
+		private ChatManager $chatManager,
+		private CommentsManager $commentsManager,
+		private IL10N $l,
+		private MessageParser $messageParser,
+		private Notifier $notifier,
+		protected IEventDispatcher $dispatcher,
+		protected ITimeFactory $timeFactory,
 	) {
-		$this->chatManager = $chatManager;
-		$this->commentsManager = $commentsManager;
-		$this->l = $l;
-		$this->messageParser = $messageParser;
-		$this->notifier = $notifier;
-		$this->timeFactory = $timeFactory;
 	}
 
 	/**
 	 * Add reaction
 	 *
-	 * @param Room $chat
-	 * @param Participant $participant
-	 * @param integer $messageId
-	 * @param string $reaction
-	 * @return IComment
 	 * @throws NotFoundException
 	 * @throws ReactionAlreadyExistsException
 	 * @throws ReactionNotSupportedException
 	 * @throws ReactionOutOfContextException
 	 */
-	public function addReactionMessage(Room $chat, Participant $participant, int $messageId, string $reaction): IComment {
-		$parentMessage = $this->getCommentToReact($chat, (string) $messageId);
+	public function addReactionMessage(Room $chat, string $actorType, string $actorId, string $actorDisplayName, int $messageId, string $reaction): IComment {
+		$parentMessage = $this->getCommentToReact($chat, (string)$messageId);
 		try {
 			// Check if the user already reacted with the same reaction
 			$this->commentsManager->getReactionComment(
-				(int) $parentMessage->getId(),
-				$participant->getAttendee()->getActorType(),
-				$participant->getAttendee()->getActorId(),
+				(int)$parentMessage->getId(),
+				$actorType,
+				$actorId,
 				$reaction
 			);
 			throw new ReactionAlreadyExistsException();
@@ -87,16 +64,23 @@ class ReactionManager {
 		}
 
 		$comment = $this->commentsManager->create(
-			$participant->getAttendee()->getActorType(),
-			$participant->getAttendee()->getActorId(),
+			$actorType,
+			$actorId,
 			'chat',
-			(string) $chat->getId()
+			(string)$chat->getId()
 		);
 		$comment->setParentId($parentMessage->getId());
 		$comment->setMessage($reaction);
 		$comment->setVerb(ChatManager::VERB_REACTION);
+
+		$event = new BeforeReactionAddedEvent($chat, $parentMessage, $actorType, $actorId, $actorDisplayName, $reaction);
+		$this->dispatcher->dispatchTyped($event);
+
 		$this->commentsManager->save($comment);
 
+		$event = new ReactionAddedEvent($chat, $parentMessage, $actorType, $actorId, $actorDisplayName, $reaction);
+		$this->dispatcher->dispatchTyped($event);
+
 		$this->notifier->notifyReacted($chat, $parentMessage, $comment);
 		return $comment;
 	}
@@ -105,7 +89,8 @@ class ReactionManager {
 	 * Delete reaction
 	 *
 	 * @param Room $chat
-	 * @param Participant $participant
+	 * @param string $actorType
+	 * @param string $actorId
 	 * @param integer $messageId
 	 * @param string $reaction
 	 * @return IComment
@@ -113,20 +98,23 @@ class ReactionManager {
 	 * @throws ReactionNotSupportedException
 	 * @throws ReactionOutOfContextException
 	 */
-	public function deleteReactionMessage(Room $chat, Participant $participant, int $messageId, string $reaction): IComment {
+	public function deleteReactionMessage(Room $chat, string $actorType, string $actorId, string $actorDisplayName, int $messageId, string $reaction): IComment {
 		// Just to verify that messageId is part of the room and throw error if not.
-		$this->getCommentToReact($chat, (string) $messageId);
+		$parentComment = $this->getCommentToReact($chat, (string)$messageId);
+
+		$event = new BeforeReactionRemovedEvent($chat, $parentComment, $actorType, $actorId, $actorDisplayName, $reaction);
+		$this->dispatcher->dispatchTyped($event);
 
 		$comment = $this->commentsManager->getReactionComment(
 			$messageId,
-			$participant->getAttendee()->getActorType(),
-			$participant->getAttendee()->getActorId(),
+			$actorType,
+			$actorId,
 			$reaction
 		);
 		$comment->setMessage(
 			json_encode([
-				'deleted_by_type' => $participant->getAttendee()->getActorType(),
-				'deleted_by_id' => $participant->getAttendee()->getActorId(),
+				'deleted_by_type' => $actorType,
+				'deleted_by_id' => $actorId,
 				'deleted_on' => $this->timeFactory->getDateTime()->getTimestamp(),
 			])
 		);
@@ -135,19 +123,26 @@ class ReactionManager {
 
 		$this->chatManager->addSystemMessage(
 			$chat,
-			$participant->getAttendee()->getActorType(),
-			$participant->getAttendee()->getActorId(),
-			json_encode(['message' => 'reaction_revoked', 'parameters' => ['message' => (int) $comment->getId()]]),
+			$actorType,
+			$actorId,
+			json_encode(['message' => 'reaction_revoked', 'parameters' => ['message' => (int)$comment->getId()]]),
 			$this->timeFactory->getDateTime(),
 			false,
 			null,
-			$messageId,
+			$parentComment,
 			true
 		);
 
+		$event = new ReactionRemovedEvent($chat, $parentComment, $actorType, $actorId, $actorDisplayName, $reaction);
+		$this->dispatcher->dispatchTyped($event);
+
 		return $comment;
 	}
 
+	/**
+	 * @return array<string, list<TalkReaction>>
+	 * @throws PreConditionNotMetException
+	 */
 	public function retrieveReactionMessages(Room $chat, Participant $participant, int $messageId, ?string $reaction = null): array {
 		if ($reaction) {
 			$comments = $this->commentsManager->retrieveAllReactionsWithSpecificReaction($messageId, $reaction);
@@ -199,7 +194,7 @@ class ReactionManager {
 		$comment = $this->commentsManager->get($messageId);
 
 		if ($comment->getObjectType() !== 'chat'
-			|| $comment->getObjectId() !== (string) $chat->getId()
+			|| $comment->getObjectId() !== (string)$chat->getId()
 			|| !in_array($comment->getVerb(), [
 				ChatManager::VERB_MESSAGE,
 				ChatManager::VERB_OBJECT_SHARED,
