@@ -2,30 +2,19 @@
 
 declare(strict_types=1);
 /**
- * @author Joachim Bauch <mail@joachim-bauch.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk;
 
-use OCA\Talk\Events\GetTurnServersEvent;
+use OCA\Talk\Events\BeforeTurnServersGetEvent;
+use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Service\RecordingService;
+use OCA\Talk\Settings\UserPreference;
 use OCA\Talk\Vendor\Firebase\JWT\JWT;
+use OCP\AppFramework\Services\IAppConfig;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
@@ -36,6 +25,7 @@ use OCP\IUserManager;
 use OCP\Security\ISecureRandom;
 
 class Config {
+	public const ALLOWED_BACKEND_TIMEOFFSET = 45;
 	public const SIGNALING_INTERNAL = 'internal';
 	public const SIGNALING_EXTERNAL = 'external';
 	public const SIGNALING_CLUSTER_CONVERSATION = 'conversation_cluster';
@@ -43,32 +33,26 @@ class Config {
 	public const SIGNALING_TICKET_V1 = 1;
 	public const SIGNALING_TICKET_V2 = 2;
 
-	protected IConfig $config;
-	protected ITimeFactory $timeFactory;
-	private IGroupManager $groupManager;
-	private IUserManager $userManager;
-	private IURLGenerator $urlGenerator;
-	private ISecureRandom $secureRandom;
-	private IEventDispatcher $dispatcher;
+	/**
+	 * Currently limiting to 1k users because the user_status API would yield
+	 * an error on Oracle otherwise. Clients should use a virtual scrolling
+	 * mechanism so the data should not be a problem nowadays
+	 */
+	public const USER_STATUS_INTEGRATION_LIMIT = 1000;
 
+	/** @var array<string, bool> */
 	protected array $canEnableSIP = [];
 
 	public function __construct(
-		IConfig $config,
-		ISecureRandom $secureRandom,
-		IGroupManager $groupManager,
-		IUserManager $userManager,
-		IURLGenerator $urlGenerator,
-		ITimeFactory $timeFactory,
-		IEventDispatcher $dispatcher,
+		protected IConfig $config,
+		protected IAppConfig $appConfig,
+		private ISecureRandom $secureRandom,
+		private IGroupManager $groupManager,
+		private IUserManager $userManager,
+		private IURLGenerator $urlGenerator,
+		protected ITimeFactory $timeFactory,
+		private IEventDispatcher $dispatcher,
 	) {
-		$this->config = $config;
-		$this->secureRandom = $secureRandom;
-		$this->groupManager = $groupManager;
-		$this->userManager = $userManager;
-		$this->urlGenerator = $urlGenerator;
-		$this->timeFactory = $timeFactory;
-		$this->dispatcher = $dispatcher;
 	}
 
 	/**
@@ -80,19 +64,30 @@ class Config {
 		return \is_array($groups) ? $groups : [];
 	}
 
+	/**
+	 * @return Participant::PRIVACY_*
+	 */
 	public function getUserReadPrivacy(string $userId): int {
-		return (int) $this->config->getUserValue(
+		return match ((int)$this->config->getUserValue(
 			$userId,
 			'spreed', 'read_status_privacy',
-			(string) Participant::PRIVACY_PUBLIC);
+			(string)Participant::PRIVACY_PUBLIC)) {
+			Participant::PRIVACY_PUBLIC => Participant::PRIVACY_PUBLIC,
+			default => Participant::PRIVACY_PRIVATE,
+		};
 	}
 
+	/**
+	 * @return Participant::PRIVACY_*
+	 */
 	public function getUserTypingPrivacy(string $userId): int {
-		return (int) $this->config->getUserValue(
+		return match ((int)$this->config->getUserValue(
 			$userId,
 			'spreed', 'typing_privacy',
-			(string) Participant::PRIVACY_PUBLIC);
-
+			(string)Participant::PRIVACY_PUBLIC)) {
+			Participant::PRIVACY_PUBLIC => Participant::PRIVACY_PUBLIC,
+			default => Participant::PRIVACY_PRIVATE,
+		};
 	}
 
 	/**
@@ -117,6 +112,16 @@ class Config {
 		return $this->config->getAppValue('spreed', 'federation_enabled', 'no') === 'yes';
 	}
 
+	public function isFederationEnabledForUserId(IUser $user): bool {
+		$allowedGroups = $this->appConfig->getAppValueArray('federation_allowed_groups', lazy: true);
+		if (empty($allowedGroups)) {
+			return true;
+		}
+
+		$userGroups = $this->groupManager->getUserGroupIds($user);
+		return !empty(array_intersect($allowedGroups, $userGroups));
+	}
+
 	public function isBreakoutRoomsEnabled(): bool {
 		return $this->config->getAppValue('spreed', 'breakout_rooms', 'yes') === 'yes';
 	}
@@ -147,6 +152,18 @@ class Config {
 		return $this->canEnableSIP[$user->getUID()];
 	}
 
+	public function canUserDialOutSIP(IUser $user): bool {
+		if (!$this->isSIPDialOutEnabled()) {
+			return false;
+		}
+
+		return $this->canUserEnableSIP($user);
+	}
+
+	public function isSIPDialOutEnabled(): bool {
+		return $this->config->getAppValue('spreed', 'sip_dialout', 'no') !== 'no';
+	}
+
 	public function getRecordingServers(): array {
 		$config = $this->config->getAppValue('spreed', 'recording_servers');
 		$recording = json_decode($config, true);
@@ -190,6 +207,28 @@ class Config {
 		return true;
 	}
 
+	/**
+	 * @return RecordingService::CONSENT_REQUIRED_*
+	 */
+	public function recordingConsentRequired(): int {
+		if (!$this->isRecordingEnabled()) {
+			return RecordingService::CONSENT_REQUIRED_NO;
+		}
+
+		return $this->getRecordingConsentConfig();
+	}
+
+	/**
+	 * @return RecordingService::CONSENT_REQUIRED_*
+	 */
+	public function getRecordingConsentConfig(): int {
+		return match ((int)$this->config->getAppValue('spreed', 'recording_consent', (string)RecordingService::CONSENT_REQUIRED_NO)) {
+			RecordingService::CONSENT_REQUIRED_YES => RecordingService::CONSENT_REQUIRED_YES,
+			RecordingService::CONSENT_REQUIRED_OPTIONAL => RecordingService::CONSENT_REQUIRED_OPTIONAL,
+			default => RecordingService::CONSENT_REQUIRED_NO,
+		};
+	}
+
 	public function getRecordingFolder(string $userId): string {
 		return $this->config->getUserValue(
 			$userId,
@@ -228,11 +267,15 @@ class Config {
 		return empty(array_intersect($allowedGroups, $userGroups));
 	}
 
+	/**
+	 * @return int<0, 255>
+	 * @psalm-return int-mask-of<Attendee::PERMISSIONS_*>
+	 */
 	public function getDefaultPermissions(): int {
 		// Admin configured default permissions
 		$configurableDefault = $this->config->getAppValue('spreed', 'default_permissions');
 		if ($configurableDefault !== '') {
-			return (int) $configurableDefault;
+			return min(Attendee::PERMISSIONS_MAX_CUSTOM, max(Attendee::PERMISSIONS_DEFAULT, (int)$configurableDefault));
 		}
 
 		// Falling back to an unrestricted set of permissions, only ignoring the lobby is off
@@ -267,19 +310,19 @@ class Config {
 
 	protected function getWebSocketDomainForSignalingServer(string $url): string {
 		$url .= '/';
-		if (strpos($url, 'https://') === 0) {
+		if (str_starts_with($url, 'https://')) {
 			return 'wss://' . substr($url, 8, strpos($url, '/', 9) - 8);
 		}
 
-		if (strpos($url, 'http://') === 0) {
+		if (str_starts_with($url, 'http://')) {
 			return 'ws://' . substr($url, 7, strpos($url, '/', 8) - 7);
 		}
 
-		if (strpos($url, 'wss://') === 0) {
+		if (str_starts_with($url, 'wss://')) {
 			return substr($url, 0, strpos($url, '/', 7));
 		}
 
-		if (strpos($url, 'ws://') === 0) {
+		if (str_starts_with($url, 'ws://')) {
 			return substr($url, 0, strpos($url, '/', 6));
 		}
 
@@ -325,7 +368,7 @@ class Config {
 		}
 
 		if ($withEvent) {
-			$event = new GetTurnServersEvent($servers);
+			$event = new BeforeTurnServersGetEvent($servers);
 			$this->dispatcher->dispatchTyped($event);
 			$servers = $event->getServers();
 		}
@@ -434,12 +477,11 @@ class Config {
 	 * @param string|null $userId
 	 * @return string
 	 */
-	public function getSignalingTicket(int $version, ?string $userId): string {
+	public function getSignalingTicket(int $version, ?string $userId, ?string $cloudId = null): string {
 		switch ($version) {
-			case self::SIGNALING_TICKET_V1:
-				return $this->getSignalingTicketV1($userId);
 			case self::SIGNALING_TICKET_V2:
-				return $this->getSignalingTicketV2($userId);
+				return $this->getSignalingTicketV2($userId, $cloudId);
+			case self::SIGNALING_TICKET_V1:
 			default:
 				return $this->getSignalingTicketV1($userId);
 		}
@@ -481,7 +523,7 @@ class Config {
 			return;
 		}
 
-		if (substr($alg, 0, 2) === 'ES') {
+		if (str_starts_with($alg, 'ES')) {
 			$privKey = openssl_pkey_new([
 				'curve_name' => 'prime256v1',
 				'private_key_bits' => 2048,
@@ -492,7 +534,7 @@ class Config {
 			if (!openssl_pkey_export($privKey, $secret)) {
 				throw new \Exception('Could not export private key');
 			}
-		} elseif (substr($alg, 0, 2) === 'RS') {
+		} elseif (str_starts_with($alg, 'RS')) {
 			$privKey = openssl_pkey_new([
 				'private_key_bits' => 2048,
 				'private_key_type' => OPENSSL_KEYTYPE_RSA,
@@ -546,21 +588,40 @@ class Config {
 		];
 	}
 
+	public function getSignalingFederatedUserData(): array {
+		/** @var Authenticator $authenticator */
+		$authenticator = \OCP\Server::get(Authenticator::class);
+		if (!$authenticator->isFederationRequest()) {
+			return [];
+		}
+
+		return [
+			'displayname' => $authenticator->getParticipant()->getAttendee()->getDisplayName(),
+		];
+	}
+
 	/**
-	 * @param string|null $userId
+	 * @param string|null $userId if given, the id of a user in this instance or
+	 *                            a cloud id.
 	 * @return string
 	 */
-	private function getSignalingTicketV2(?string $userId): string {
+	private function getSignalingTicketV2(?string $userId, ?string $cloudId): string {
 		$timestamp = $this->timeFactory->getTime();
 		$data = [
 			'iss' => $this->urlGenerator->getAbsoluteURL(''),
 			'iat' => $timestamp,
 			'exp' => $timestamp + 60,  // Valid for 1 minute.
 		];
-		$user = !empty($userId) ? $this->userManager->get($userId) : null;
+		$user = $userId !== null ? $this->userManager->get($userId) : null;
 		if ($user instanceof IUser) {
 			$data['sub'] = $user->getUID();
 			$data['userdata'] = $this->getSignalingUserData($user);
+		} elseif ($cloudId !== null && $cloudId !== '') {
+			$data['sub'] = $cloudId;
+			$extendedData = $this->getSignalingFederatedUserData();
+			if (!empty($extendedData)) {
+				$data['userdata'] = $extendedData;
+			}
 		}
 
 		$alg = $this->getSignalingTokenAlgorithm();
@@ -597,10 +658,87 @@ class Config {
 	}
 
 	public function getGridVideosLimit(): int {
-		return (int) $this->config->getAppValue('spreed', 'grid_videos_limit', '19'); // 5*4 - self
+		return (int)$this->config->getAppValue('spreed', 'grid_videos_limit', '19'); // 5*4 - self
 	}
 
 	public function getGridVideosLimitEnforced(): bool {
 		return $this->config->getAppValue('spreed', 'grid_videos_limit_enforced', 'no') === 'yes';
 	}
+
+	/**
+	 * User setting falling back to admin defined app config
+	 *
+	 * @param ?string $userId
+	 * @return bool
+	 */
+	public function getCallsStartWithoutMedia(?string $userId): bool {
+		if ($userId !== null) {
+			$userSetting = $this->config->getUserValue($userId, 'spreed', UserPreference::CALLS_START_WITHOUT_MEDIA);
+			if ($userSetting === 'yes' || $userSetting === 'no') {
+				return $userSetting === 'yes';
+			}
+		}
+
+		return $this->appConfig->getAppValueBool('calls_start_without_media');
+	}
+
+	/**
+	 * User setting for blur background
+	 *
+	 * @param ?string $userId
+	 * @return bool
+	 */
+	public function getBlurVirtualBackground(?string $userId): bool {
+		if ($userId !== null) {
+			$userSetting = $this->config->getUserValue($userId, 'spreed', UserPreference::BLUR_VIRTUAL_BACKGROUND);
+			return $userSetting === 'yes';
+		}
+		return false;
+	}
+
+	/**
+	 * User setting for conversations list style
+	 *
+	 * @param ?string $userId
+	 * @return UserPreference::CONVERSATION_LIST_STYLE_*
+	 */
+	public function getConversationsListStyle(?string $userId): string {
+		if ($userId !== null) {
+			$userSetting = $this->config->getUserValue(
+				$userId,
+				'spreed',
+				UserPreference::CONVERSATIONS_LIST_STYLE,
+				UserPreference::CONVERSATION_LIST_STYLE_TWO_LINES
+			);
+
+			if (in_array($userSetting, [UserPreference::CONVERSATION_LIST_STYLE_TWO_LINES, UserPreference::CONVERSATION_LIST_STYLE_COMPACT], true)) {
+				return $userSetting;
+			}
+		}
+		return UserPreference::CONVERSATION_LIST_STYLE_TWO_LINES;
+	}
+
+	/**
+	 * User setting falling back to admin defined app config
+	 */
+	public function getInactiveLockTime(): int {
+		return $this->appConfig->getAppValueInt('inactivity_lock_after_days');
+	}
+
+	public function enableLobbyOnLockedRooms(): bool {
+		return $this->appConfig->getAppValueBool('inactivity_enable_lobby');
+	}
+
+	public function isPasswordEnforced(): bool {
+		return $this->appConfig->getAppValueBool('force_passwords');
+	}
+
+	public function isCallEndToEndEncryptionEnabled(): bool {
+		if ($this->getSignalingMode() !== self::SIGNALING_EXTERNAL) {
+			return false;
+		}
+
+		// TODO Default value will be set to true, once all mobile clients support it.
+		return $this->appConfig->getAppValueBool('call_end_to_end_encryption');
+	}
 }
