@@ -2,41 +2,24 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2018 Joas Schilling <coding@schilljs.com>
- *
- * @author Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 namespace OCA\Talk\Migration;
 
 use Doctrine\DBAL\Schema\SchemaException;
-use Doctrine\DBAL\Types\Types;
 use OCP\DB\ISchemaWrapper;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\DB\Types;
 use OCP\IDBConnection;
 use OCP\Migration\IOutput;
 use OCP\Migration\SimpleMigrationStep;
 
 class Version7000Date20190724121136 extends SimpleMigrationStep {
-	protected IDBConnection $connection;
 
-	public function __construct(IDBConnection $connection) {
-		$this->connection = $connection;
+	public function __construct(
+		protected IDBConnection $connection,
+	) {
 	}
 
 	/**
@@ -96,9 +79,9 @@ class Version7000Date20190724121136 extends SimpleMigrationStep {
 
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
-			$update->setParameter('message_id', (int) $row['last_comment'], IQueryBuilder::PARAM_INT)
+			$update->setParameter('message_id', (int)$row['last_comment'], IQueryBuilder::PARAM_INT)
 				->setParameter('user_id', $row['user_id'])
-				->setParameter('room_id', (int) $row['object_id'], IQueryBuilder::PARAM_INT);
+				->setParameter('room_id', (int)$row['object_id'], IQueryBuilder::PARAM_INT);
 			$update->executeStatement();
 		}
 		$result->closeCursor();
