@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Search;
@@ -26,7 +11,9 @@ namespace OCA\Talk\Search;
 use OCA\Talk\AppInfo\Application;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Chat\MessageParser;
+use OCA\Talk\Config;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Exceptions\RoomNotFoundException;
 use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Manager as RoomManager;
 use OCA\Talk\Model\Attendee;
@@ -38,36 +25,32 @@ use OCP\Comments\IComment;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 use OCP\IUser;
+use OCP\IUserSession;
+use OCP\Search\FilterDefinition;
+use OCP\Search\IFilter;
+use OCP\Search\IFilteringProvider;
 use OCP\Search\IProvider;
 use OCP\Search\ISearchQuery;
 use OCP\Search\SearchResult;
 use OCP\Search\SearchResultEntry;
 
-class MessageSearch implements IProvider {
-	protected RoomManager $roomManager;
-	protected ParticipantService $participantService;
-	protected ChatManager $chatManager;
-	protected MessageParser $messageParser;
-	protected ITimeFactory $timeFactory;
-	protected IURLGenerator $url;
-	protected IL10N $l;
+class MessageSearch implements IProvider, IFilteringProvider {
+
+	public const CONVERSATION_FILTER = 'conversation';
+
+	protected bool $isConversationFiltered = false;
 
 	public function __construct(
-		RoomManager $roomManager,
-		ParticipantService $participantService,
-		ChatManager $chatManager,
-		MessageParser $messageParser,
-		ITimeFactory $timeFactory,
-		IURLGenerator $url,
-		IL10N $l,
+		protected RoomManager $roomManager,
+		protected ParticipantService $participantService,
+		protected ChatManager $chatManager,
+		protected MessageParser $messageParser,
+		protected ITimeFactory $timeFactory,
+		protected IURLGenerator $url,
+		protected IL10N $l,
+		protected Config $talkConfig,
+		protected IUserSession $userSession,
 	) {
-		$this->roomManager = $roomManager;
-		$this->participantService = $participantService;
-		$this->chatManager = $chatManager;
-		$this->messageParser = $messageParser;
-		$this->timeFactory = $timeFactory;
-		$this->url = $url;
-		$this->l = $l;
 	}
 
 	/**
@@ -87,8 +70,13 @@ class MessageSearch implements IProvider {
 	/**
 	 * @inheritDoc
 	 */
-	public function getOrder(string $route, array $routeParameters): int {
-		if (strpos($route, Application::APP_ID . '.') === 0) {
+	public function getOrder(string $route, array $routeParameters): ?int {
+		$currentUser = $this->userSession->getUser();
+		if ($currentUser && $this->talkConfig->isDisabledForUser($currentUser)) {
+			return null;
+		}
+
+		if (str_starts_with($route, Application::APP_ID . '.')) {
 			// Active app, prefer Talk results
 			return -2;
 		}
@@ -104,6 +92,9 @@ class MessageSearch implements IProvider {
 	}
 
 	protected function getSublineTemplate(): string {
+		if ($this->isConversationFiltered) {
+			return $this->l->t('{user}');
+		}
 		return $this->l->t('{user} in {conversation}');
 	}
 
@@ -112,19 +103,47 @@ class MessageSearch implements IProvider {
 	 */
 	public function search(IUser $user, ISearchQuery $query): SearchResult {
 		$title = $this->l->t('Messages');
-		if ($this->getCurrentConversationToken($query) !== '') {
+		$currentToken = $this->getCurrentConversationToken($query);
+		if ($currentToken !== '') {
 			$title = $this->l->t('Messages in other conversations');
 		}
 
-		$rooms = $this->roomManager->getRoomsForUser($user->getUID());
+		$filter = $query->getFilter(self::CONVERSATION_FILTER);
+		if ($filter && $filter->get() !== $currentToken) {
+			$this->isConversationFiltered = true;
+			$title = $this->l->t('Messages');
 
+			try {
+				$rooms = [$this->roomManager->getRoomForUserByToken(
+					$filter->get(),
+					$user->getUID()
+				)];
+			} catch (RoomNotFoundException) {
+				return SearchResult::complete($title, []);
+			}
+		} elseif ($filter) {
+			// The filter is the "Current conversation" so the CurrentMessageSearch will handle it
+			return SearchResult::complete($title, []);
+		} else {
+			$rooms = $this->roomManager->getRoomsForUser($user->getUID());
+		}
+
+		return $this->performSearch($user, $query, $title, $rooms, $this->isConversationFiltered);
+	}
+
+	/**
+	 * @param Room[] $rooms
+	 */
+	public function performSearch(IUser $user, ISearchQuery $query, string $title, array $rooms, bool $isCurrentMessageSearch = false): SearchResult {
 		$roomMap = [];
 		foreach ($rooms as $room) {
-			if ($room->getType() === Room::TYPE_CHANGELOG) {
+			if (!$isCurrentMessageSearch &&
+				$room->getType() === Room::TYPE_CHANGELOG) {
 				continue;
 			}
 
-			if ($this->getCurrentConversationToken($query) === $room->getToken()) {
+			if (!$isCurrentMessageSearch &&
+				$this->getCurrentConversationToken($query) === $room->getToken()) {
 				// No search result from current conversation
 				continue;
 			}
@@ -136,21 +155,47 @@ class MessageSearch implements IProvider {
 				}
 			}
 
-			$roomMap[(string) $room->getId()] = $room;
+			if ($room->isFederatedConversation()) {
+				continue;
+			}
+
+			$roomMap[(string)$room->getId()] = $room;
 		}
 
 		if (empty($roomMap)) {
-			return SearchResult::complete(
-				$this->l->t('Messages'),
-				[]
-			);
+			return SearchResult::complete($title, []);
 		}
 
-		$offset = (int) $query->getCursor();
-		$comments = $this->chatManager->searchForObjects(
+		// Apply filters when available
+		$lowerTimeBoundary = $upperTimeBoundary = $actorType = $actorId = null;
+		if ($since = $query->getFilter(IFilter::BUILTIN_SINCE)?->get()) {
+			if ($since instanceof \DateTimeImmutable) {
+				$lowerTimeBoundary = $since;
+			}
+		}
+
+		if ($until = $query->getFilter(IFilter::BUILTIN_UNTIL)?->get()) {
+			if ($until instanceof \DateTimeImmutable) {
+				$upperTimeBoundary = $until;
+			}
+		}
+
+		if ($person = $query->getFilter(IFilter::BUILTIN_PERSON)?->get()) {
+			if ($person instanceof IUser) {
+				$actorType = Attendee::ACTOR_USERS;
+				$actorId = $person->getUID();
+			}
+		}
+
+		$offset = (int)$query->getCursor();
+		$comments = $this->chatManager->searchForObjectsWithFilters(
 			$query->getTerm(),
 			array_keys($roomMap),
-			ChatManager::VERB_MESSAGE,
+			[ChatManager::VERB_MESSAGE, ChatManager::VERB_OBJECT_SHARED],
+			$lowerTimeBoundary,
+			$upperTimeBoundary,
+			$actorType,
+			$actorId,
 			$offset,
 			$query->getLimit()
 		);
@@ -160,8 +205,7 @@ class MessageSearch implements IProvider {
 			$room = $roomMap[$comment->getObjectId()];
 			try {
 				$result[] = $this->commentToSearchResultEntry($room, $user, $comment, $query);
-			} catch (UnauthorizedException $e) {
-			} catch (ParticipantNotFoundException $e) {
+			} catch (UnauthorizedException|ParticipantNotFoundException) {
 			}
 		}
 
@@ -172,10 +216,14 @@ class MessageSearch implements IProvider {
 		);
 	}
 
+	/**
+	 * @throws ParticipantNotFoundException
+	 * @throws UnauthorizedException
+	 */
 	protected function commentToSearchResultEntry(Room $room, IUser $user, IComment $comment, ISearchQuery $query): SearchResultEntry {
 		$participant = $this->participantService->getParticipant($room, $user->getUID(), false);
 
-		$id = (int) $comment->getId();
+		$id = (int)$comment->getId();
 		$message = $this->messageParser->createMessage($room, $participant, $comment, $this->l);
 		$this->messageParser->parseMessage($message);
 
@@ -222,7 +270,7 @@ class MessageSearch implements IProvider {
 		}
 
 		$displayName = $message->getActorDisplayName();
-		if ($message->getActorType() === Attendee::ACTOR_GUESTS) {
+		if (in_array($message->getActorType(), [Attendee::ACTOR_GUESTS, Attendee::ACTOR_EMAILS], true)) {
 			if ($displayName === '') {
 				$displayName = $this->l->t('Guest');
 			} else {
@@ -251,4 +299,24 @@ class MessageSearch implements IProvider {
 
 		return $entry;
 	}
+
+	public function getSupportedFilters(): array {
+		return [
+			IFilter::BUILTIN_TERM,
+			IFilter::BUILTIN_SINCE,
+			IFilter::BUILTIN_UNTIL,
+			IFilter::BUILTIN_PERSON,
+			self::CONVERSATION_FILTER,
+		];
+	}
+
+	public function getAlternateIds(): array {
+		return ['talk-message'];
+	}
+
+	public function getCustomFilters(): array {
+		return [
+			new FilterDefinition(self::CONVERSATION_FILTER)
+		];
+	}
 }
