@@ -11,7 +11,11 @@ namespace OCA\Talk\Settings;
 class UserPreference {
 	public const BLUR_VIRTUAL_BACKGROUND = 'blur_virtual_background';
 	public const CALLS_START_WITHOUT_MEDIA = 'calls_start_without_media';
+	public const CONVERSATIONS_LIST_STYLE = 'conversations_list_style';
 	public const PLAY_SOUNDS = 'play_sounds';
 	public const TYPING_PRIVACY = 'typing_privacy';
 	public const READ_STATUS_PRIVACY = 'read_status_privacy';
+
+	public const CONVERSATION_LIST_STYLE_TWO_LINES = 'two-lines';
+	public const CONVERSATION_LIST_STYLE_COMPACT = 'compact';
 }
